@@ -338,6 +338,8 @@ static int dummy_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
   curr->mode = mode;
 
+  if (RIG_PASSBAND_NOCHANGE == width) return RIG_OK;
+
   if (width == RIG_PASSBAND_NORMAL)
     curr->width = rig_passband_normal(rig, mode);
   else
@@ -423,9 +425,9 @@ static int dummy_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
   // as if it had keyed us
   switch (rig->state.pttport.type.ptt)
     {
-    case RIG_PTT_SERIAL_DTR: ser_get_dtr (&rig->state.pttport, &status); break;
-    case RIG_PTT_SERIAL_RTS: ser_get_rts (&rig->state.pttport, &status); break;
-    case RIG_PTT_PARALLEL: par_ptt_get (&rig->state.pttport, &par_status); break;
+    case RIG_PTT_SERIAL_DTR: if (rig->state.pttport.fd >= 0) ser_get_dtr (&rig->state.pttport, &status); break;
+    case RIG_PTT_SERIAL_RTS: if (rig->state.pttport.fd >= 0) ser_get_rts (&rig->state.pttport, &status); break;
+    case RIG_PTT_PARALLEL: if (rig->state.pttport.fd >= 0) par_ptt_get (&rig->state.pttport, &par_status); break;
     default: break;
     }
   *ptt = *ptt || status || RIG_PTT_ON == par_status;
@@ -626,6 +628,8 @@ static int dummy_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t
   		rig_strvfo(vfo), rig_strrmode(tx_mode), buf);
 
   curr->tx_mode = tx_mode;
+  if (RIG_PASSBAND_NOCHANGE == tx_width) return RIG_OK;
+
   curr->tx_width = tx_width;
 
   return RIG_OK;
