@@ -2,6 +2,7 @@
  *  Hamlib Rotator backend - Easycom
  *  Copyright (c) 2001-2003 by Stephane Fillod
  *  Contributed by Francois Retief <fgretief@sun.ac.za>
+ *  Copyright (c) 2014 by Alexander Schultze <alexschultze@gmail.com>
  *
  *
  *   This library is free software; you can redistribute it and/or
@@ -37,8 +38,6 @@
 
 #include "easycomm.h"
 
-#define USE_CUSTOM_CODE 1
-
 /* ************************************************************************* */
 /**
  *  easycomm_transaction
@@ -53,25 +52,36 @@
 static int
 easycomm_transaction (ROT *rot, const char *cmdstr, char *data, size_t data_len)
 {
-	struct rot_state *rs;
-    int retval;
+  struct rot_state *rs;
+  int retval;
 
-	rs = &rot->state;
-	retval = write_block(&rs->rotport, cmdstr, strlen(cmdstr));
-	if (retval != RIG_OK) {
-		return retval;
-	}
+  rig_debug(RIG_DEBUG_TRACE, "%s called: %s\n", __FUNCTION__, cmdstr);
 
-    if (data == NULL || data_len <= 0)
-        return RIG_OK;  /* don't want a reply */
+  if (!rot )
+    return -RIG_EINVAL;
 
-    retval = read_string(&rs->rotport, data, data_len, "\n", 1);
-    if (retval < 0)
-        return retval;  /* error */
+  rs = &rot->state;
+  serial_flush(&rs->rotport);
+  retval = write_block(&rs->rotport, cmdstr, strlen(cmdstr));
+  if (retval != RIG_OK) {
+      goto transaction_quit;
+  }
 
-    /* TODO: Error checking */
+  if (data == NULL || data_len <= 0)
+    return RIG_OK;  /* don't want a reply */
 
-    return RIG_OK;
+  memset(data,0,data_len);
+  retval = read_string(&rs->rotport, data, data_len, "\n", 1);
+  if (retval < 0) {
+    rig_debug(RIG_DEBUG_TRACE, "%s read_string failed with status %d\n", __FUNCTION__, retval);
+    goto transaction_quit;
+  } else {
+    rig_debug(RIG_DEBUG_TRACE, "%s read_string: %s\n", __FUNCTION__, data);
+    retval = RIG_OK;
+  }
+
+  transaction_quit:
+  return retval;
 }
 
 /* ************************************************************************* */
@@ -97,58 +107,25 @@ easycomm_rot_get_position(ROT *rot, azimuth_t *az, elevation_t *el)
 {
     char cmdstr[16], ackbuf[32];
     int retval;
-    int t;
 
     rig_debug(RIG_DEBUG_TRACE, "%s called\n", __FUNCTION__);
 
-#ifdef USE_CUSTOM_CODE
-    sprintf(cmdstr, "!");   /* Custom implementation: Remove later */
-#else
     sprintf(cmdstr, "AZ EL \n");
-#endif
 
     retval = easycomm_transaction(rot, cmdstr, ackbuf, sizeof(ackbuf));
 	if (retval != RIG_OK) {
-		return retval;
+	  rig_debug(RIG_DEBUG_TRACE, "%s got error: %d\n", __FUNCTION__, retval);
+	  return retval;
 	}
 
     /* Parse parse string to extract AZ,EL values */
-#ifdef USE_CUSTOM_CODE
-    retval = sscanf(ackbuf, "TM%i AZ%f EL%f", &t, az, el);
-    if (retval != 3) {
-        rig_debug(RIG_DEBUG_ERR, "%s: unknown replay (%s)\n", __FUNCTION__, ackbuf);
+    rig_debug(RIG_DEBUG_TRACE, "%s got response: %s\n", __FUNCTION__, ackbuf);
+    retval = sscanf(ackbuf, "AZ%f EL%f", az, el);
+    if (retval != 2) {
+        rig_debug(RIG_DEBUG_ERR, "%s: unknown response (%s)\n", __FUNCTION__, ackbuf);
         return -RIG_ERJCTED;
     }
-#ifndef USETESTCODE
-    /* Correct for desimal point. */
-    *az /= 10.0;
-    *el /= 10.0;
-#else
-    /* Debugging code, remove later */
-
-    rig_debug(RIG_DEBUG_TRACE, "  (az, el) = (%.1f, %.1f)\n", *az, *el);
-
-    *az /= 10.0;
-    *el /= 10.0;
-
-    rig_debug(RIG_DEBUG_TRACE, "  (az, el) = (%f, %f)\n", *az, *el);
-    rig_debug(RIG_DEBUG_TRACE, "  (az, el) = (%.2f, %.2f)\n", *az, *el);
-
-    /* Note: For some reason I found that the result of this expression
-     * does not give accurate results.
-     * The first printf give the correct value.
-     * The second printf give incorrect value, while
-     * the third printf give correct values.
-     *
-     * I get  az = 42.79999 when it should be 42.8
-     */
-#endif
-
-#else
-    *az = 45.3;
-    *el = 10.3;
-#endif
-	return RIG_OK;
+    return RIG_OK;
 }
 
 static int
@@ -203,7 +180,7 @@ easycomm_rot_move(ROT *rot, int direction, int speed)
     int retval;
     rig_debug(RIG_DEBUG_TRACE, "%s called\n", __FUNCTION__);
 
-    /* Note: speed is unused at the moment */
+   /* For EasyComm 1/2/3 */
     switch (direction) {
     case ROT_MOVE_UP:       /* Elevation increase */
         sprintf(cmdstr, "MU\n");
@@ -229,6 +206,153 @@ easycomm_rot_move(ROT *rot, int direction, int speed)
     return RIG_OK;
 }
 
+static int
+easycomm_rot_move_velocity(ROT *rot, int direction, int speed)
+{
+    char cmdstr[24], ackbuf[32];
+    int retval;
+    rig_debug(RIG_DEBUG_TRACE, "%s called\n", __FUNCTION__);
+    if(speed<0 && speed>9999)
+       rig_debug(RIG_DEBUG_ERR,"%s: Invalid speed value!(0-9999) (%d)\n", __FUNCTION__, speed);
+       return -RIG_EINVAL;
+
+    /* Speed for EasyComm 3 */
+    switch (direction) {
+    case ROT_MOVE_UP:       /* Elevation increase */
+        sprintf(cmdstr, "VU%04d\n", speed);
+        break;
+    case ROT_MOVE_DOWN:     /* Elevation decrease */
+        sprintf(cmdstr, "VD%04d\n", speed);
+        break;
+    case ROT_MOVE_LEFT:     /* Azimuth decrease */
+        sprintf(cmdstr, "VL%04d\n", speed);
+        break;
+    case ROT_MOVE_RIGHT:    /* Azimuth increase */
+        sprintf(cmdstr, "VR%04d\n", speed);
+        break;
+    default:
+        rig_debug(RIG_DEBUG_ERR,"%s: Invalid direction value! (%d)\n", __FUNCTION__, direction);
+        return -RIG_EINVAL;
+    }
+
+    retval = easycomm_transaction(rot, cmdstr, ackbuf, sizeof(ackbuf));
+    if (retval != RIG_OK)
+        return retval;
+
+    return RIG_OK;
+}
+
+/*
+ * Get Info
+ * returns the model name string
+ */
+static const char * easycomm_rot_get_info(ROT *rot)
+{
+	const struct rot_caps *rc;
+
+	rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+	if (!rot)
+		return (const char *)-RIG_EINVAL;
+
+	rc = rot->caps;
+
+	return rc->model_name;
+}
+
+/*
+ * Receive status / configuration / output
+ *
+ * For configuration registers, *val must contain string of register e.g. '0'-'f'
+ */
+
+static int easycomm_rot_get_conf(ROT *rot, token_t token, char *val) {
+	char cmdstr[16], ackbuf[32];
+	int retval;
+
+	rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+	rig_debug(RIG_DEBUG_TRACE, "%s: token = %d", __func__, token);
+
+	if (!rot)
+		return -RIG_EINVAL;
+		
+	switch(token) {
+	case TOK_GET_STATUS:
+		sprintf(cmdstr, "GS\n;");
+		break;
+	case TOK_GET_ERRORS:
+		sprintf(cmdstr, "GE\n;");
+		break;
+	case TOK_GET_INPUT:
+		sprintf(cmdstr, "IP\n;");
+		break;
+	case TOK_GET_ANALOG_INPUT:
+		sprintf(cmdstr, "AN\n;");
+		break;
+	case TOK_GET_VERSION:
+		sprintf(cmdstr, "VE\n;");
+		break;	
+	case TOK_GET_CONFIG:
+		sprintf(cmdstr, "CR %c\n;",*val);
+		break;		
+	default:
+	
+	
+		return -RIG_EINVAL;
+	}
+	rig_debug(RIG_DEBUG_TRACE, "%s: cmdstr = %s, *val = %c\n", __func__, cmdstr, *val);
+
+
+
+	retval = easycomm_transaction(rot, cmdstr, ackbuf, sizeof(ackbuf));
+	
+	if (retval != RIG_OK) {
+	  rig_debug(RIG_DEBUG_TRACE, "%s got error: %d\n", __FUNCTION__, retval);
+	  return retval;
+	}
+
+   
+    rig_debug(RIG_DEBUG_TRACE, "%s got response: %s\n", __FUNCTION__, ackbuf);
+     /* Return given string at correct position*/
+		val = &ackbuf[2]; /* CCxxxxxx */
+    return RIG_OK;
+}
+
+/*
+ * Set configuration
+ *
+ * For configuration registers, *val must contain char of register e.g. '0'-'f' followed by setting
+ * e.g. x,yyyyy
+ */
+
+static int easycomm_rot_set_conf(ROT *rot, token_t token, const char *val) {
+	char cmdstr[16], ackbuf[32];
+	int retval;
+
+	rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+	rig_debug(RIG_DEBUG_TRACE, "%s: token = %d", __func__, token);
+
+	if (!rot)
+		return -RIG_EINVAL;
+		
+	switch(token) {
+	case TOK_SET_CONFIG:
+		sprintf(cmdstr, "CW%s\n;",val);
+		break;		
+	default:
+		return -RIG_EINVAL;
+	}
+	rig_debug(RIG_DEBUG_TRACE, "%s: cmdstr = %s, *val = %c\n", __func__, cmdstr, *val);
+
+	retval = easycomm_transaction(rot, cmdstr, ackbuf, sizeof(ackbuf));
+	
+	if (retval != RIG_OK) {
+	  rig_debug(RIG_DEBUG_TRACE, "%s got error: %d\n", __FUNCTION__, retval);
+	  return retval;
+	}
+    return RIG_OK;
+}
+
 /* ************************************************************************* */
 /*
  * Easycomm rotator capabilities.
@@ -242,7 +366,7 @@ const struct rot_caps easycomm1_rot_caps = {
   .rot_model =      ROT_MODEL_EASYCOMM1,
   .model_name =     "EasycommI",
   .mfg_name =       "Hamlib",
-  .version =        "0.3",
+  .version =        "0.4",
   .copyright = 	 "LGPL",
   .status =         RIG_STATUS_BETA,
   .rot_type =       ROT_TYPE_OTHER,
@@ -267,6 +391,7 @@ const struct rot_caps easycomm1_rot_caps = {
 
   .set_position =  easycomm_rot_set_position,
   .stop = 	easycomm_rot_stop,
+  .get_info =  easycomm_rot_get_info,
 };
 
 /* EasycommII implement most of the functions. Again the radio tags
@@ -276,7 +401,7 @@ const struct rot_caps easycomm2_rot_caps = {
   .rot_model =      ROT_MODEL_EASYCOMM2,
   .model_name =     "EasycommII",
   .mfg_name =       "Hamlib",
-  .version =        "0.3",
+  .version =        "0.4",
   .copyright = 	 "LGPL",
   .status =         RIG_STATUS_BETA,
   .rot_type =       ROT_TYPE_OTHER,
@@ -310,8 +435,54 @@ const struct rot_caps easycomm2_rot_caps = {
   .park =  easycomm_rot_park,
   .reset =  easycomm_rot_reset,
   .move =  easycomm_rot_move,
+  .set_conf = easycomm_rot_set_conf,
+  .get_conf = easycomm_rot_get_conf,
+  .get_info =  easycomm_rot_get_info,
+};
 
-  .get_info =  NULL,
+/* EasycommIII provides changes Moving functions and info.
+ */
+const struct rot_caps easycomm3_rot_caps = {
+  .rot_model =      ROT_MODEL_EASYCOMM3,
+  .model_name =     "EasycommIII",
+  .mfg_name =       "Hamlib",
+  .version =        "0.4",
+  .copyright = 	 "LGPL",
+  .status =         RIG_STATUS_ALPHA,
+  .rot_type =       ROT_TYPE_OTHER,
+  .port_type =      RIG_PORT_SERIAL,
+  .serial_rate_min =  9600,
+  .serial_rate_max =  19200,
+  .serial_data_bits =  8,
+  .serial_stop_bits =  1,
+  .serial_parity =  RIG_PARITY_NONE,
+  .serial_handshake =  RIG_HANDSHAKE_NONE,
+  .write_delay =  0,
+  .post_write_delay =  0,
+  .timeout =  200,
+  .retry =  3,
+
+  .min_az = 	0.0,
+  .max_az =  	360.0,
+  .min_el = 	0.0,
+  .max_el =  	180.0,
+
+  .priv =  NULL,	/* priv */
+
+  .rot_init =  NULL,
+  .rot_cleanup =  NULL,
+  .rot_open =  NULL,
+  .rot_close =  NULL,
+
+  .get_position =  easycomm_rot_get_position,
+  .set_position =  easycomm_rot_set_position,
+  .stop = 	easycomm_rot_stop,
+  .park =  easycomm_rot_park,
+  .reset =  easycomm_rot_reset,
+  .move =  easycomm_rot_move_velocity,
+  .set_conf = easycomm_rot_set_conf,
+  .get_conf = easycomm_rot_get_conf,
+  .get_info =  easycomm_rot_get_info,
 };
 
 /* ************************************************************************* */
@@ -322,10 +493,9 @@ DECLARE_INITROT_BACKEND(easycomm)
 
     rot_register(&easycomm1_rot_caps);
     rot_register(&easycomm2_rot_caps);
-
+    rot_register(&easycomm3_rot_caps);
 	return RIG_OK;
 }
 
 /* ************************************************************************* */
 /* end of file */
-
