@@ -46,12 +46,14 @@ static int ic706_r2i_mode(RIG *rig, rmode_t mode, pbwidth_t width,
 	err = rig2icom_mode(rig, mode, width, md, pd);
 
 	if (err != RIG_OK)
-	    return err;
+		return err;
 
+	if (width != RIG_PASSBAND_NOCHANGE) {
     if (*pd == -1)
-		*pd = PD_MEDIUM_2;
+			*pd = PD_MEDIUM_2;
     else
-		(*pd)--;
+			(*pd)--;
+	}
 
 	return RIG_OK;
 }
