@@ -1,6 +1,6 @@
 /*
  *  Hamlib CI-V backend - main header
- *  Copyright (c) 2000-2015 by Stephane Fillod
+ *  Copyright (c) 2000-2016 by Stephane Fillod
  *
  *
  *   This library is free software; you can redistribute it and/or
@@ -111,6 +111,7 @@ struct icom_priv_caps {
 						       tokens to bandwidth and
 						       mode */
 	int serial_full_duplex; /*!< Whether RXD&TXD are not tied together */
+	unsigned char civ_version; // default to 0, 1=IC7200,IC7300,etc differences
 };
 
 
@@ -118,7 +119,10 @@ struct icom_priv_data {
 	unsigned char re_civ_addr;	/* the remote equipment's CI-V address*/
 	int civ_731_mode; /* Off: freqs on 10 digits, On: freqs on 8 digits */
 	int no_xchg; /* Off: use VFO XCHG to set other VFO, On: use set VFO to set other VFO */
+	int no_1a_03_cmd;							/* rig doesn't tell IF widths */
+	int split_on;									/* record split state */
 	pltstate_t *pltstate;	/* only on optoscan */
+	unsigned char civ_version; /* 0=default, 1=new commands for IC7200,IC7300, etc */
 };
 
 extern const struct ts_sc_list r8500_ts_sc_list[];
@@ -133,6 +137,7 @@ extern const struct ts_sc_list ic706_ts_sc_list[];
 extern const struct ts_sc_list ic7000_ts_sc_list[];
 extern const struct ts_sc_list ic7100_ts_sc_list[];
 extern const struct ts_sc_list ic7200_ts_sc_list[];
+extern const struct ts_sc_list ic7300_ts_sc_list[];
 extern const struct ts_sc_list ic910_ts_sc_list[];
 extern const struct ts_sc_list ic718_ts_sc_list[];
 
@@ -158,6 +163,8 @@ int icom_set_split_freq(RIG *rig, vfo_t vfo, freq_t tx_freq);
 int icom_get_split_freq(RIG *rig, vfo_t vfo, freq_t *tx_freq);
 int icom_set_split_mode(RIG *rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width);
 int icom_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *tx_mode, pbwidth_t *tx_width);
+int icom_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t tx_freq, rmode_t tx_mode, pbwidth_t tx_width);
+int icom_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *tx_freq, rmode_t *tx_mode, pbwidth_t *tx_width);
 int icom_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t tx_vfo);
 int icom_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo);
 int icom_mem_get_split_vfo(RIG *rig, vfo_t vfo, split_t *split, vfo_t *tx_vfo);
@@ -178,6 +185,8 @@ int icom_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op);
 int icom_scan(RIG *rig, vfo_t vfo, scan_t scan, int ch);
 int icom_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 int icom_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
+int icom_set_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t val);
+int icom_get_ext_level(RIG *rig, vfo_t vfo, token_t token, value_t *val);
 int icom_set_func(RIG *rig, vfo_t vfo, setting_t func, int status);
 int icom_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status);
 int icom_set_parm(RIG *rig, setting_t parm, value_t val);
@@ -189,6 +198,9 @@ int icom_get_powerstat(RIG *rig, powerstat_t *status);
 int icom_set_ant(RIG * rig, vfo_t vfo, ant_t ant);
 int icom_get_ant(RIG * rig, vfo_t vfo, ant_t *ant);
 int icom_decode_event(RIG *rig);
+int icom_power2mW(RIG * rig, unsigned int *mwpower, float power, freq_t freq, rmode_t mode);
+int icom_mW2power(RIG * rig, float *power, unsigned int mwpower, freq_t freq, rmode_t mode);
+int icom_send_morse (RIG * rig, vfo_t vfo, const char *msg);
 
 extern const struct confparams icom_cfg_params[];
 
@@ -223,6 +235,7 @@ extern const struct rig_caps ic7800_caps;
 extern const struct rig_caps ic7000_caps;
 extern const struct rig_caps ic7100_caps;
 extern const struct rig_caps ic7200_caps;
+extern const struct rig_caps ic7300_caps;
 extern const struct rig_caps ic781_caps;
 extern const struct rig_caps ic820h_caps;
 extern const struct rig_caps ic821h_caps;
@@ -255,5 +268,8 @@ extern const struct rig_caps os535_caps;
 extern const struct rig_caps ic92d_caps;
 extern const struct rig_caps id1_caps;
 extern const struct rig_caps id5100_caps;
+extern const struct rig_caps ic2730_caps;
+
+extern const struct rig_caps perseus_caps;
 
 #endif /* _ICOM_H */
