@@ -1,6 +1,6 @@
 /*
  *  Hamlib CI-V backend - defines for the ICOM "CI-V" interface.
- *  Copyright (c) 2000-2010 by Stephane Fillod
+ *  Copyright (c) 2000-2016 by Stephane Fillod
  *
  *
  *   This library is free software; you can redistribute it and/or
@@ -84,7 +84,7 @@
 #define C_CTL_ANT	0x12		/* Set/get antenna, Sc */
 #define C_CTL_ANN	0x13		/* Control announce (speech synth.), Sc */
 #define C_CTL_LVL	0x14		/* Set AF/RF/squelch, Sc */
-#define C_RD_SQSM	0x15		/* Read squelch condiction/S-meter level, Sc */
+#define C_RD_SQSM	0x15		/* Read squelch condition/S-meter level, Sc */
 #define C_CTL_FUNC	0x16		/* Function settings (AGC,NB,etc.), Sc */
 #define C_SND_CW	0x17		/* Send CW message */
 #define C_SET_PWR	0x18		/* Set Power ON/OFF, Sc */
@@ -92,6 +92,7 @@
 #define C_CTL_MEM	0x1a		/* Misc memory/bank/rig control functions, Sc */
 #define C_SET_TONE	0x1b		/* Set tone frequency */
 #define C_CTL_PTT	0x1c		/* Control Transmit On/Off, Sc */
+#define C_CTL_MTEXT	0x70		/* Microtelecom Extension */
 #define C_CTL_MISC	0x7f		/* Miscellaneous control, Sc */
 
 /*
@@ -294,6 +295,7 @@
  */
 #define S_PWR_OFF	0x00
 #define S_PWR_ON	0x01
+#define S_PWR_STDBY	0x02
 
 /*
  * Transmit control (C_CTL_PTT) subcommands
@@ -324,8 +326,8 @@
 #define S_MEM_SATMEM        0x01    /* Satellite memory */
 #define S_MEM_VOXGAIN       0x02    /* VOX gain level (0=0%, 255=100%) */
 #define S_MEM_VOXDELAY      0x03    /* VOX delay (0=0.0 sec, 20=2.0 sec) */
+#define S_MEM1_VOXDELAY     0x05    /* VOX delay (0=0.0 sec, 20=2.0 sec) */
 #define S_MEM_ANTIVOX       0x04    /* anti VOX setting */
-#define S_MEM_ATTLEVEL      0x05    /* Attenuation level (0=0%, 255=100%) */
 #define S_MEM_RIT           0x06    /* RIT (0=off, 1=on, 2=sub dial) */
 #define S_MEM_SATMODE       0x07    /* Satellite mode (on/off) */
 #define S_MEM_BANDSCOPE     0x08    /* Simple bandscope (on/off) */
@@ -391,6 +393,7 @@
 #define TOK_RTTY_FLTR TOKEN_BACKEND(100)
 #define TOK_SSBBASS TOKEN_BACKEND(101)
 #define TOK_SQLCTRL TOKEN_BACKEND(102)
+#define TOK_LEVEL_MONITOR TOKEN_BACKEND(103)
 
 
 #endif /* _ICOM_DEFS_H */
