@@ -211,7 +211,10 @@
 #define RIG_MODEL_ICRX7 RIG_MAKE_MODEL(RIG_ICOM, 69)
 #define RIG_MODEL_IC7100 RIG_MAKE_MODEL(RIG_ICOM, 70)
 #define RIG_MODEL_ID5100 RIG_MAKE_MODEL(RIG_ICOM, 71)
-/* next one is 72 */
+#define RIG_MODEL_IC2730 RIG_MAKE_MODEL(RIG_ICOM, 72)
+#define RIG_MODEL_IC7300 RIG_MAKE_MODEL(RIG_ICOM, 73)
+#define RIG_MODEL_PERSEUS RIG_MAKE_MODEL(RIG_ICOM, 74)
+/* next one is 75 */
 
 	/*
 	 * Optoelectronics (CI-V)
