@@ -53,7 +53,7 @@ int ic10_cmd_trim (char *data, int data_len) {
 				__func__, data_len);
 
        /* suck up additional spaces at end of the data buffer */
-        for (i=data_len; !isdigit(data[i-1]); i--) {
+        for (i=data_len; !isdigit((int)data[i-1]); i--) {
                data_len = data_len-1;
         	rig_debug(RIG_DEBUG_TRACE,"%s: data['%d'] is '%c'\n",
                                 __func__, i-1, data[i-1]);
@@ -107,7 +107,7 @@ static int get_ic10_if (RIG *rig, char *data)
 	int i, data_len, retval=!RIG_OK;
 
 	for (i=0; retval!=RIG_OK && i < rig->caps->retry; i++) {
-		data_len = 38;
+		data_len = 37;
 		retval = ic10_transaction (rig, "IF;", 3, data, &data_len);
 		if (retval != RIG_OK)
 			continue;
