@@ -93,7 +93,7 @@ const struct rig_caps k3_caps = {
 	.rig_model =		RIG_MODEL_K3,
 	.model_name =		"K3/KX3",
 	.mfg_name =		"Elecraft",
-	.version =		"20130118",
+	.version =		"20161116",
 	.copyright =		"LGPL",
 	.status =		RIG_STATUS_BETA,
 	.rig_type =		RIG_TYPE_TRANSCEIVER,
@@ -191,6 +191,7 @@ const struct rig_caps k3_caps = {
 	.rig_init =		kenwood_init,
 	.rig_cleanup =		kenwood_cleanup,
 	.rig_open =		elecraft_open,
+	.rig_close =		kenwood_close,
 	.set_freq =		kenwood_set_freq,
 	.get_freq =		kenwood_get_freq,
 	.set_mode =		k3_set_mode,
@@ -376,34 +377,36 @@ int k3_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 	if (err != RIG_OK)
 		return err;
 
-	/* and set the requested bandwidth.  On my K3, the bandwidth is rounded
-	 * down to the nearest 50 Hz, i.e. sending BW0239; will cause the bandwidth
-	 * to be set to 2.350 kHz.  As the width must be divided by 10, 10 Hz values
-	 * between 0 and 4 round down to the nearest 100 Hz and values between 5
-	 * and 9 round down to the nearest 50 Hz.
-	 *
-	 * width string value must be padded with leading '0' to equal four
-	 * characters.
-	 */
+	if (width != RIG_PASSBAND_NOCHANGE) {
+		/* and set the requested bandwidth.  On my K3, the bandwidth is rounded
+		 * down to the nearest 50 Hz, i.e. sending BW0239; will cause the bandwidth
+		 * to be set to 2.350 kHz.  As the width must be divided by 10, 10 Hz values
+		 * between 0 and 4 round down to the nearest 100 Hz and values between 5
+		 * and 9 round down to the nearest 50 Hz.
+		 *
+		 * width string value must be padded with leading '0' to equal four
+		 * characters.
+		 */
 
-	/* passband widths vary by mode so gather lower and upper limits */
-	pbwidth_t pb_nar = rig_passband_narrow(rig, mode);
-	pbwidth_t pb_wid = rig_passband_wide(rig, mode);
+		/* passband widths vary by mode so gather lower and upper limits */
+		pbwidth_t pb_nar = rig_passband_narrow(rig, mode);
+		pbwidth_t pb_wid = rig_passband_wide(rig, mode);
 
-	if (width < 0)
-		width = labs(width);
+		if (width < 0)
+			width = labs(width);
 
-	if (width == RIG_PASSBAND_NORMAL)
-		width = rig_passband_normal(rig, mode);
-	else if (width < pb_nar)
-		width = pb_nar;
-	else if (width > pb_wid)
-		width = pb_wid;
+		if (width == RIG_PASSBAND_NORMAL)
+			width = rig_passband_normal(rig, mode);
+		else if (width < pb_nar)
+			width = pb_nar;
+		else if (width > pb_wid)
+			width = pb_wid;
 
-	sprintf(cmd_s, "BW%04ld", width / 10);
-	err = kenwood_transaction(rig, cmd_s, NULL, 0);
-	if (err != RIG_OK)
-		return err;
+		sprintf(cmd_s, "BW%04ld", width / 10);
+		err = kenwood_transaction(rig, cmd_s, NULL, 0);
+		if (err != RIG_OK)
+			return err;
+	}
 
 	/* Now set data sub-mode.  K3 needs to be in a DATA mode before setting
 	 * the sub-mode.
@@ -622,6 +625,18 @@ int k3_set_split_mode(RIG * rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
       break;
     }
 
+#if 0
+  /* Set data sub-mode.  K3 needs to be in a DATA mode before setting
+   * the sub-mode or switching to VFOB so we do this before the MD$ command.
+   */
+  if (tx_mode == RIG_MODE_PKTLSB || tx_mode == RIG_MODE_PKTUSB
+      || tx_mode == RIG_MODE_RTTY || tx_mode == RIG_MODE_RTTYR) {
+    err = kenwood_transaction(rig, cmd_m, NULL, 0);
+    if (err != RIG_OK)
+      return err;
+  }
+#endif
+
   struct kenwood_priv_caps *caps = kenwood_caps(rig);
   char buf[6];
   char kmode;
@@ -638,44 +653,37 @@ int k3_set_split_mode(RIG * rig, vfo_t vfo, rmode_t tx_mode, pbwidth_t tx_width)
   if (err != RIG_OK)
     return err;
 
-  /* and set the requested bandwidth.  On my K3, the bandwidth is rounded
-   * down to the nearest 50 Hz, i.e. sending BW0239; will cause the bandwidth
-   * to be set to 2.350 kHz.  As the width must be divided by 10, 10 Hz values
-   * between 0 and 4 round down to the nearest 100 Hz and values between 5
-   * and 9 round down to the nearest 50 Hz.
-   *
-   * tx_width string value must be padded with leading '0' to equal four
-   * characters.
-   */
+	if (tx_width != RIG_PASSBAND_NOCHANGE) {
+		/* and set the requested bandwidth.  On my K3, the bandwidth is rounded
+		 * down to the nearest 50 Hz, i.e. sending BW0239; will cause the bandwidth
+		 * to be set to 2.350 kHz.  As the width must be divided by 10, 10 Hz values
+		 * between 0 and 4 round down to the nearest 100 Hz and values between 5
+		 * and 9 round down to the nearest 50 Hz.
+		 *
+		 * tx_width string value must be padded with leading '0' to equal four
+		 * characters.
+		 */
 
-  /* passband widths vary by mode so gather lower and upper limits */
-  pbwidth_t pb_nar = rig_passband_narrow(rig, tx_mode);
-  pbwidth_t pb_wid = rig_passband_wide(rig, tx_mode);
+		/* passband widths vary by mode so gather lower and upper limits */
+		pbwidth_t pb_nar = rig_passband_narrow(rig, tx_mode);
+		pbwidth_t pb_wid = rig_passband_wide(rig, tx_mode);
 
-  if (tx_width < 0)
-    tx_width = labs(tx_width);
+		if (tx_width < 0)
+			tx_width = labs(tx_width);
 
-  if (tx_width == RIG_PASSBAND_NORMAL)
-    tx_width = rig_passband_normal(rig, tx_mode);
-  else if (tx_width < pb_nar)
-    tx_width = pb_nar;
-  else if (tx_width > pb_wid)
-    tx_width = pb_wid;
+		if (tx_width == RIG_PASSBAND_NORMAL)
+			tx_width = rig_passband_normal(rig, tx_mode);
+		else if (tx_width < pb_nar)
+			tx_width = pb_nar;
+		else if (tx_width > pb_wid)
+			tx_width = pb_wid;
 
-  sprintf(cmd_s, "BW$%04ld", tx_width / 10);
-  err = kenwood_transaction(rig, cmd_s, NULL, 0);
-  if (err != RIG_OK)
-    return err;
+		sprintf(cmd_s, "BW$%04ld", tx_width / 10);
+		err = kenwood_transaction(rig, cmd_s, NULL, 0);
+		if (err != RIG_OK)
+			return err;
+	}
 
-  /* Now set data sub-mode.  K3 needs to be in a DATA mode before setting
-   * the sub-mode.
-   */
-  if (tx_mode == RIG_MODE_PKTLSB || tx_mode == RIG_MODE_PKTUSB
-      || tx_mode == RIG_MODE_RTTY || tx_mode == RIG_MODE_RTTYR) {
-    err = kenwood_transaction(rig, cmd_m, NULL, 0);
-    if (err != RIG_OK)
-      return err;
-  }
 
   return RIG_OK;
 }
