@@ -205,6 +205,7 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
   if (!rig || (!cmdstr && !datasize) || (datasize && !data))
     return -RIG_EINVAL;
 
+  struct kenwood_priv_data * priv = rig->state.priv;
   struct kenwood_priv_caps *caps = kenwood_caps(rig);
   struct rig_state *rs;
   int retval;
@@ -212,12 +213,6 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
   char *cmd;
   int len;
   int retry_read = 0;
-  static char const std_verify[] = "ID;"; /* command we can always
-                                             send to any rig even when
-                                             the rig is busy */
-  static char const shrt_verify[] = ";"; /* alternate short verify
-                                            command XG3 etc. */
-  char const * verify = ',' == cmdstr[1] ? shrt_verify : std_verify;
 
   rs = &rig->state;
   rs->hold_decode = 1;
@@ -262,16 +257,18 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
     /* no reply expected so we need to write a command that always
        gives a reply so we can read any error replies from the actual
        command being sent without blocking */
-    if (RIG_OK != (retval = write_block (&rs->rigport, verify, strlen (verify)))) {
+    if (RIG_OK != (retval = write_block (&rs->rigport, priv->verify_cmd
+                                         , strlen (priv->verify_cmd)))) {
       goto transaction_quit;
     }
   }
 
+ transaction_read:
   /* allow one extra byte for terminator we don't return */
-  len = min (datasize ? datasize + 1 : strlen (verify) + 7, KENWOOD_MAX_BUF_LEN);
+  len = min (datasize ? datasize + 1 : strlen (priv->verify_cmd) + 13, KENWOOD_MAX_BUF_LEN);
   retval = read_string(&rs->rigport, buffer, len, cmdtrm, strlen(cmdtrm));
   if (retval < 0) {
-    if (retry_read++ < rig->caps->retry)
+    if (retry_read++ < rs->rigport.retry)
       goto transaction_write;
     goto transaction_quit;
   }
@@ -279,7 +276,7 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
   /* Check that command termination is correct */
   if (strchr(cmdtrm, buffer[strlen(buffer)-1])==NULL) {
     rig_debug(RIG_DEBUG_ERR, "%s: Command is not correctly terminated '%s'\n", __func__, buffer);
-    if (retry_read++ < rig->caps->retry)
+    if (retry_read++ < rs->rigport.retry)
       goto transaction_write;
     retval = -RIG_EPROTO;
     goto transaction_quit;
@@ -301,7 +298,7 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
         {
           rig_debug(RIG_DEBUG_VERBOSE, "%s: Overflow for '%s'\n", __func__, cmdstr);
         }
-      if (retry_read++ < rig->caps->retry)
+      if (retry_read++ < rs->rigport.retry)
         goto transaction_write;
       retval = -RIG_EPROTO;
       goto transaction_quit;
@@ -311,7 +308,7 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
         {
           rig_debug(RIG_DEBUG_VERBOSE, "%s: Communication error for '%s'\n", __func__, cmdstr);
         }
-      if (retry_read++ < rig->caps->retry)
+      if (retry_read++ < rs->rigport.retry)
         goto transaction_write;
       retval = -RIG_EIO;
       goto transaction_quit;
@@ -321,11 +318,11 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
         {
           rig_debug(RIG_DEBUG_ERR, "%s: Unknown command or rig busy '%s'\n", __func__, cmdstr);
         }
-      if (retry_read++ < rig->caps->retry)
+      if (retry_read++ < rs->rigport.retry)
         {
           rig_debug(RIG_DEBUG_ERR, "%s: Retrying shortly\n", __func__);
           usleep (rig->caps->timeout * 1000);
-          goto transaction_write;
+          goto transaction_read;
         }
       retval = -RIG_ERJCTED;
       goto transaction_quit;
@@ -350,7 +347,7 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
           rig_debug(RIG_DEBUG_ERR, "%s: wrong reply %c%c for command %c%c\n",
                     __func__, buffer[0], buffer[1], cmdstr[0], cmdstr[1]);
 
-          if (retry_read++ < rig->caps->retry)
+          if (retry_read++ < rs->rigport.retry)
             goto transaction_write;
 
           retval =  -RIG_EPROTO;
@@ -368,7 +365,8 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
     }
   else
     {
-      if (verify[0] != buffer[0] || (verify[1] && verify[1] != buffer[1]))
+      if (priv->verify_cmd[0] != buffer[0]
+          || (priv->verify_cmd[1] && priv->verify_cmd[1] != buffer[1]))
         {
           /*
            * TODO: When RIG_TRN is enabled, we can pass the string to
@@ -376,9 +374,10 @@ int kenwood_transaction(RIG *rig, const char *cmdstr, char *data, size_t datasiz
            * commands.
            */
           rig_debug(RIG_DEBUG_ERR, "%s: wrong reply %c%c for command verification %c%c\n",
-                    __func__, buffer[0], buffer[1], verify[0], verify[1]);
+                    __func__, buffer[0], buffer[1]
+                    , priv->verify_cmd[0], priv->verify_cmd[1]);
 
-          if (retry_read++ < rig->caps->retry)
+          if (retry_read++ < rs->rigport.retry)
             goto transaction_write;
 
           retval =  -RIG_EPROTO;
@@ -442,7 +441,7 @@ int kenwood_safe_transaction(RIG *rig, const char *cmd, char *buf,
           err =  -RIG_EPROTO;
           usleep (rig->caps->timeout * 1000);
         }
-    } while (err != RIG_OK && ++retry < rig->caps->retry);
+    } while (err != RIG_OK && ++retry < rig->state.rigport.retry);
 
   return err;
 }
@@ -487,9 +486,9 @@ int kenwood_init(RIG *rig)
     return -RIG_ENOMEM;
 
   memset(priv, 0x00, sizeof(struct kenwood_priv_data));
-
+  strcpy (priv->verify_cmd, RIG_MODEL_XG3 == rig->caps->rig_model ? ";" : "ID;");
   priv->split = RIG_SPLIT_OFF;
-
+  priv->trn_state = -1;
   rig->state.priv = priv;
 
   /* default mode_table */
@@ -525,6 +524,7 @@ int kenwood_open(RIG *rig)
   if (!rig)
     return -RIG_EINVAL;
 
+  struct kenwood_priv_data *priv = rig->state.priv;
   int err, i;
   char *idptr;
   char id[KENWOOD_MAX_BUF_LEN];
@@ -533,7 +533,6 @@ int kenwood_open(RIG *rig)
     {
       /* we need the firmware version for these rigs to deal with f/w defects */
       static char fw_version[7];
-      struct kenwood_priv_data * priv = rig->state.priv;
 
       err = kenwood_transaction (rig, "FV", fw_version, sizeof (fw_version));
       if (RIG_OK != err)
@@ -559,10 +558,29 @@ int kenwood_open(RIG *rig)
 
   /* get id in buffer, will be null terminated */
   err = kenwood_get_id(rig, id);
-  if (err != RIG_OK) {
-    rig_debug(RIG_DEBUG_ERR, "%s: cannot get identification\n", __func__);
-    return err;
-  }
+  if (RIG_MODEL_XG3 != rig->caps->rig_model && -RIG_ETIMEOUT == err)
+    {
+      /* Some Kenwood emulations have no ID command response :(
+       * Try an FA command to see is anyone is listening */
+      char buffer[KENWOOD_MAX_BUF_LEN];
+      err = kenwood_transaction (rig, "FA", buffer, sizeof (buffer));
+      if (RIG_OK != err)
+        {
+          rig_debug (RIG_DEBUG_ERR, "%s: no response from rig\n", __func__);
+          return err;
+        }
+      /* here we know there is something that responds to FA but not
+         to ID so use FA as the command verification command */
+      strcpy (priv->verify_cmd, "FA;");
+      strcpy (id, "ID019");     /* fake a TS-2000 */
+    }
+  else
+    {
+      if (err != RIG_OK) {
+        rig_debug(RIG_DEBUG_ERR, "%s: cannot get identification\n", __func__);
+        return err;
+      }
+    }
 
   /* id is something like 'IDXXX' or 'ID XXX' */
   if (strlen(id) < 5) {
@@ -595,15 +613,15 @@ int kenwood_open(RIG *rig)
     rig_debug(RIG_DEBUG_TRACE, "%s: found match %s\n",
         __func__, kenwood_id_string_list[i].id);
 
-    if (kenwood_id_string_list[i].model == rig->caps->rig_model)
-      {
-        /* Currently we cannot cope with AI mode so turn it off in
-           case last client left it on */
-        kenwood_set_trn(rig, RIG_TRN_OFF); /* ignore status in case
-                                              it's not supported */
-
-        return RIG_OK;
-      }
+    if (kenwood_id_string_list[i].model == rig->caps->rig_model) {
+      /* get current AI state so it can be restored */
+      kenwood_get_trn (rig, &priv->trn_state); /* ignore errors */
+      /* Currently we cannot cope with AI mode so turn it off in
+         case last client left it on */
+      kenwood_set_trn(rig, RIG_TRN_OFF); /* ignore status in case
+                                            it's not supported */
+      return RIG_OK;
+    }
 
     /* driver mismatch */
     rig_debug(RIG_DEBUG_ERR,
@@ -621,6 +639,21 @@ int kenwood_open(RIG *rig)
 }
 
 
+int kenwood_close(RIG *rig)
+{
+  rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+  if (!rig) return -RIG_EINVAL;
+  struct kenwood_priv_data *priv = rig->state.priv;
+  if (!no_restore_ai && priv->trn_state >= 0)
+    {
+      /* restore AI state */
+      kenwood_set_trn (rig, priv->trn_state); /* ignore status in case
+                                                 it's not supported */
+    }
+  return RIG_OK;
+}
+
+
 /* ID
  *  Reads transceiver ID number
  *
@@ -695,6 +728,25 @@ int kenwood_set_vfo(RIG *rig, vfo_t vfo)
     return -RIG_EINVAL;
   }
 
+  //if rig=ts2000 then check Satellite mode status
+  if(rig->caps->rig_model == RIG_MODEL_TS2000) {
+	  char retbuf[20];
+	  rig_debug(RIG_DEBUG_VERBOSE, "Checking Satellite mode status\n");
+	  sprintf(cmdbuf, "SA");
+
+	  retval = kenwood_transaction(rig, cmdbuf, retbuf, 20);
+	  if (retval != RIG_OK)
+	    return retval;
+
+	  rig_debug(RIG_DEBUG_VERBOSE, "Satellite mode status %s\n",retbuf);
+	  //Satellite mode ON
+	  if(retbuf[2]=='1') {
+		  //SAT mode doesn't allow FR command (cannot select VFO)
+		  //selecting VFO is useless in SAT MODE
+		  return RIG_OK;
+		  }
+	  }
+
   sprintf(cmdbuf, "FR%c", vfo_function);
 
   if (rig->caps->rig_model == RIG_MODEL_TS50
@@ -815,7 +867,6 @@ int kenwood_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
       rig_debug(RIG_DEBUG_ERR, "%s: unsupported VFO %d\n", __func__, vfo);
       return -RIG_EINVAL;
     }
-
     /* set RX VFO */
     sprintf(cmdbuf, "FR%c", vfo_function);
     retval = kenwood_transaction(rig, cmdbuf, NULL, 0);
@@ -842,6 +893,15 @@ int kenwood_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
     rig_debug(RIG_DEBUG_ERR, "%s: unsupported VFO %d\n", __func__, txvfo);
     return -RIG_EINVAL;
   }
+  if (RIG_MODEL_K2 == rig->caps->rig_model
+      || RIG_MODEL_K3 == rig->caps->rig_model) {
+    /* do not attempt redundant split change commands on Elecraft as
+       they impact output power when transmitting */
+    if (RIG_OK == (retval = kenwood_safe_transaction (rig, "FT", cmdbuf, sizeof (cmdbuf), 3)))
+      {
+        if (cmdbuf[2] == vfo_function) return RIG_OK;
+      }
+  }
   /* set TX VFO */
   sprintf(cmdbuf, "FT%c", vfo_function);
   retval = kenwood_transaction(rig, cmdbuf, NULL, 0);
@@ -938,7 +998,10 @@ int kenwood_get_split_vfo_if(RIG *rig, vfo_t rxvfo, split_t *split, vfo_t *txvfo
   priv->split = *split;
 
   /* find where is the txvfo.. */
-  int transmitting = '1' == priv->info[28];
+  /* Elecraft info[30] does not track split VFO when transmitting */
+  int transmitting = '1' == priv->info[28]
+    && RIG_MODEL_K2 != rig->caps->rig_model
+    && RIG_MODEL_K3 != rig->caps->rig_model;
   switch (priv->info[30])
     {
     case '0':
@@ -984,8 +1047,12 @@ int kenwood_get_vfo_if(RIG *rig, vfo_t *vfo)
   if (retval != RIG_OK)
     return retval;
 
-  int split_and_transmitting = '1' == priv->info[32] && '1' == priv->info[28];
-
+  /* Elecraft info[30] does not track split VFO when transmitting */
+  int split_and_transmitting =
+    '1' == priv->info[28] /* transmitting */
+    && '1' == priv->info[32]               /* split */
+    && RIG_MODEL_K2 != rig->caps->rig_model
+    && RIG_MODEL_K3 != rig->caps->rig_model;
   switch (priv->info[30])
     {
     case '0':
@@ -1041,7 +1108,7 @@ int kenwood_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
     rig_debug(RIG_DEBUG_ERR, "%s: unsupported VFO %d\n", __func__, vfo);
     return -RIG_EINVAL;
   }
-  sprintf(freqbuf, "F%c%011ld", vfo_letter, (long)freq);
+  sprintf(freqbuf, "F%c%011"PRIll, vfo_letter, (int64_t)freq);
 
   int err = kenwood_transaction(rig, freqbuf, NULL, 0);
 
@@ -1388,6 +1455,7 @@ int kenwood_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 	}
     }
 
+  if (RIG_PASSBAND_NOCHANGE == width) return RIG_OK;
   if (rig->caps->rig_model == RIG_MODEL_TS450S
       || rig->caps->rig_model == RIG_MODEL_TS690S
       || rig->caps->rig_model == RIG_MODEL_TS850
@@ -2516,13 +2584,11 @@ int kenwood_set_trn(RIG *rig, int trn)
 
   if (RIG_MODEL_TS990S == rig->caps->rig_model)
     {
-      return kenwood_simple_transaction(rig,
-                                        (trn == RIG_TRN_RIG) ? "AI2" : "AI0", 0);
+      return kenwood_transaction(rig, (trn == RIG_TRN_RIG) ? "AI2" : "AI0", NULL, 0);
     }
   else
     {
-      return kenwood_simple_transaction(rig,
-                                        (trn == RIG_TRN_RIG) ? "AI1" : "AI0", 0);
+      return kenwood_transaction(rig, (trn == RIG_TRN_RIG) ? "AI1" : "AI0", NULL, 0);
     }
 }
 
@@ -2536,6 +2602,15 @@ int kenwood_get_trn(RIG *rig, int *trn)
   if (!rig || !trn)
     return -RIG_EINVAL;
 
+  /* these rigs only have AI[0|1] set commands and no AI query */
+  if (rig->caps->rig_model == RIG_MODEL_TS450S
+      || rig->caps->rig_model == RIG_MODEL_TS690S
+      || rig->caps->rig_model == RIG_MODEL_TS790
+      || rig->caps->rig_model == RIG_MODEL_TS850
+      || rig->caps->rig_model == RIG_MODEL_TS950SDX) {
+    return -RIG_ENAVAIL;
+  }
+
   char trnbuf[6];
   int retval;
 
@@ -2558,8 +2633,7 @@ int kenwood_set_powerstat(RIG *rig, powerstat_t status)
   if (!rig)
     return -RIG_EINVAL;
 
-  return kenwood_simple_transaction(rig,
-    (status == RIG_POWER_ON) ? "PS1" : "PS0", 4);
+  return kenwood_transaction(rig, (status == RIG_POWER_ON) ? "PS1" : "PS0", NULL, 0);
 }
 
 /*
@@ -3134,7 +3208,7 @@ DECLARE_PROBERIG_BACKEND(kenwood)
   /*
    * reply should be something like 'IDxxx;'
    */
-  if (id_len != 5 || id_len != 6) {
+  if (id_len != 5 && id_len != 6) {
     idbuf[7] = '\0';
     rig_debug(RIG_DEBUG_VERBOSE, "probe_kenwood: protocol error, "
           " expected %d, received %d: %s\n",
