@@ -196,14 +196,13 @@ int transfox_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 const char* transfox_get_info(RIG *rig)
 {
 	static char firmbuf[32];
-    size_t firmlen = sizeof firmbuf;
 	int retval;
 
 	rig_debug(RIG_DEBUG_TRACE, "%s called\n", __func__);
 
     firmbuf[0] = '\0';
 
-	retval = kenwood_transaction(rig, "CS", 2, firmbuf, &firmlen);
+		retval = kenwood_transaction(rig, "CS", firmbuf, sizeof (firmbuf));
 	if (retval != RIG_OK)
 		return NULL;
 
@@ -220,24 +219,24 @@ int transfox_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
 	case RIG_LEVEL_ATT:
 		if (val.i == 0) {
-			ret = kenwood_simple_cmd(rig, "C30");
+			ret = kenwood_transaction(rig, "C30", NULL, 0);
 			if (ret != RIG_OK)
 				return ret;
-			ret = kenwood_simple_cmd(rig, "C20");
+			ret = kenwood_transaction(rig, "C20", NULL, 0);
 			if (ret != RIG_OK)
 				return ret;
         } else if (val.i == 10) {
-				ret = kenwood_simple_cmd(rig, "C30");
+			ret = kenwood_transaction(rig, "C30", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
-				ret = kenwood_simple_cmd(rig, "C21");
+				ret = kenwood_transaction(rig, "C21", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
         } else if (val.i == 20) {
-				ret = kenwood_simple_cmd(rig, "C31");
+			ret = kenwood_transaction(rig, "C31", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
-				ret = kenwood_simple_cmd(rig, "C21");
+				ret = kenwood_transaction(rig, "C21", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
 		}
@@ -245,24 +244,24 @@ int transfox_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 
 	case RIG_LEVEL_PREAMP:
 		if (val.i == 0) {
-			ret = kenwood_simple_cmd(rig, "C30");
+			ret = kenwood_transaction(rig, "C30", NULL, 0);
 			if (ret != RIG_OK)
 				return ret;
-			ret = kenwood_simple_cmd(rig, "C20");
+			ret = kenwood_transaction(rig, "C20", NULL, 0);
 			if (ret != RIG_OK)
 				return ret;
         } else if (val.i == 22) {
-				ret = kenwood_simple_cmd(rig, "C30");
+			ret = kenwood_transaction(rig, "C30", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
-				ret = kenwood_simple_cmd(rig, "C22");
+				ret = kenwood_transaction(rig, "C22", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
         } else if (val.i == 44) {
-				ret = kenwood_simple_cmd(rig, "C32");
+			ret = kenwood_transaction(rig, "C32", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
-				ret = kenwood_simple_cmd(rig, "C22");
+				ret = kenwood_transaction(rig, "C22", NULL, 0);
 				if (ret != RIG_OK)
 					return ret;
 		}
