@@ -2,21 +2,20 @@
  *  Hamlib Kenwood backend - TRC-80 description
  *  Copyright (c) 2000-2009 by Stephane Fillod
  *
- *	$Id: trc80.c,v 1.1 2009-01-29 22:54:40 fillods Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -114,12 +113,12 @@ const struct rig_caps trc80_caps = {
 		RIG_CHAN_END,
 	},
 
-.rx_range_list1 =  { 
+.rx_range_list1 =  {
 	{kHz(500),MHz(30),TRC80_ALL_MODES,-1,-1,TRC80_VFO},
 	RIG_FRNG_END,
   }, /* rx range */
 
-.tx_range_list1 =  { 
+.tx_range_list1 =  {
 	{MHz(1.8),MHz(30),TRC80_OTHER_TX_MODES,W(15),W(100),TRC80_VFO,TRC80_ANTS},
 	{MHz(1.8),MHz(30),TRC80_AM_TX_MODES,W(5),W(25),TRC80_VFO,TRC80_ANTS},	/* AM class */
 	RIG_FRNG_END,
