@@ -156,6 +156,7 @@ static int ts570_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
   retval = kenwood_transaction(rig, buf, NULL, 0);
   if (retval != RIG_OK) return retval;
 
+	if (RIG_PASSBAND_NOCHANGE == width) return retval;
   switch (mode)
   {
     case RIG_MODE_CW:
@@ -804,6 +805,7 @@ const struct rig_caps ts570s_caps = {
 .priv =  (void *)&ts570_priv_caps,
 
 .rig_init = kenwood_init,
+.rig_open = kenwood_open,
 .rig_cleanup = kenwood_cleanup,
 .set_freq =  kenwood_set_freq,
 .get_freq =  kenwood_get_freq,
@@ -988,6 +990,7 @@ const struct rig_caps ts570d_caps = {
 .priv =  (void *)&ts570_priv_caps,
 
 .rig_init = kenwood_init,
+.rig_open = kenwood_open,
 .rig_cleanup = kenwood_cleanup,
 .set_freq =  kenwood_set_freq,
 .get_freq =  kenwood_get_freq,
