@@ -58,12 +58,11 @@
 
 
 /* Some type definitions needed for dll access */
-typedef enum _tFrontendMode
-{
-  eFrontendModeUndefined  = 0,
-  eFrontendModeDrm    = 1,
-  eFrontendModeAm     = 2,
-  eFrontendModeFm     = 6,
+typedef enum _tFrontendMode {
+	eFrontendModeUndefined  = 0,
+	eFrontendModeDrm    = 1,
+	eFrontendModeAm     = 2,
+	eFrontendModeFm     = 6,
 } tFrontendMode;
 
 typedef short (__stdcall *FNCFrontendOpen)(void);
@@ -132,7 +131,7 @@ static int dwtdll_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width);
 static int dwtdll_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width);
 static int dwtdll_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val);
 static int dwtdll_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val);
-static const char * dwtdll_get_info(RIG *rig);
+static const char *dwtdll_get_info(RIG *rig);
 
 /*
  * Coding Technologies Digital World Traveller DRM tuner.
@@ -143,79 +142,79 @@ static const char * dwtdll_get_info(RIG *rig);
  */
 
 const struct rig_caps dwt_caps = {
-.rig_model =  RIG_MODEL_DWT,
-.model_name = "Digital World Traveller",
-.mfg_name =  "Coding Technologies",
-.version =  "0.1.1",
-.copyright =  "LGPL",
-.status =  RIG_STATUS_STABLE,
-.rig_type =  RIG_TYPE_PCRECEIVER,
-.ptt_type =  RIG_PTT_NONE,
-.dcd_type =  RIG_DCD_NONE,
-.port_type =  RIG_PORT_NONE,
-.write_delay =  0,
-.post_write_delay =  0,
-.timeout =  200,
-.retry = 0,
+	.rig_model =		RIG_MODEL_DWT,
+	.model_name =		"Digital World Traveller",
+	.mfg_name =		"Coding Technologies",
+	.version =		"0.1.1",
+	.copyright =		"LGPL",
+	.status =		RIG_STATUS_STABLE,
+	.rig_type =		RIG_TYPE_PCRECEIVER,
+	.ptt_type =		RIG_PTT_NONE,
+	.dcd_type =		RIG_DCD_NONE,
+	.port_type =		RIG_PORT_NONE,
+	.write_delay =		0,
+	.post_write_delay =	0,
+	.timeout =		200,
+	.retry =		0,
 
-.has_get_func =  DWT_FUNC,
-.has_set_func =  DWT_FUNC,
-.has_get_level =  DWT_LEVEL_ALL,
-.has_set_level =  RIG_LEVEL_SET(DWT_LEVEL_ALL),
-.has_get_parm =  DWT_PARM_ALL,
-.has_set_parm =  RIG_PARM_SET(DWT_PARM_ALL),
-.level_gran =  {},
-.parm_gran =  {},
-.ctcss_list =  NULL,
-.dcs_list =  NULL,
-.preamp =   { RIG_DBLST_END },
-.attenuator =     { 20, RIG_DBLST_END, },	/* TBC */
-.max_rit =  Hz(0),
-.max_xit =  Hz(0),
-.max_ifshift =  Hz(0),
-.targetable_vfo =  0,
-.transceive =  RIG_TRN_OFF,
-.bank_qty =   0,
-.chan_desc_sz =  0,
+	.has_get_func =		DWT_FUNC,
+	.has_set_func =		DWT_FUNC,
+	.has_get_level =	DWT_LEVEL_ALL,
+	.has_set_level =	RIG_LEVEL_SET(DWT_LEVEL_ALL),
+	.has_get_parm =		DWT_PARM_ALL,
+	.has_set_parm =		RIG_PARM_SET(DWT_PARM_ALL),
+	.level_gran =		{},
+	.parm_gran =		{},
+	.ctcss_list =		NULL,
+	.dcs_list =		NULL,
+	.preamp =		{ RIG_DBLST_END },
+	.attenuator =		{ 20, RIG_DBLST_END, },	/* TBC */
+	.max_rit =		Hz(0),
+	.max_xit =		Hz(0),
+	.max_ifshift =		Hz(0),
+	.targetable_vfo =	0,
+	.transceive =		RIG_TRN_OFF,
+	.bank_qty =		0,
+	.chan_desc_sz =		0,
 
-.chan_list =  { RIG_CHAN_END, },
+	.chan_list =		{ RIG_CHAN_END, },
 
-.rx_range_list1 =  {
-    {kHz(150),MHz(30)-kHz(1),DWT_MODES,-1,-1,DWT_VFO,DWT_ANT},
-    {kHz(87.5),MHz(108),RIG_MODE_WFM,-1,-1,DWT_VFO,DWT_ANT},
-	RIG_FRNG_END,
-  },
-.tx_range_list1 =  { RIG_FRNG_END, },
-.rx_range_list2 =  {
-    {kHz(150),MHz(30)-kHz(1),DWT_MODES,-1,-1,DWT_VFO,DWT_ANT},
-    {kHz(87.5),MHz(108),RIG_MODE_WFM,-1,-1,DWT_VFO,DWT_ANT},
-	RIG_FRNG_END,
-  },
-.tx_range_list2 =  { RIG_FRNG_END, },
-.tuning_steps =  {
-	 {DWT_MODES,1},
-	 RIG_TS_END,
+	.rx_range_list1 = {
+		{kHz(150), MHz(30) - kHz(1), DWT_MODES, -1, -1, DWT_VFO, DWT_ANT},
+		{kHz(87.5), MHz(108), RIG_MODE_WFM, -1, -1, DWT_VFO, DWT_ANT},
+		RIG_FRNG_END,
 	},
-        /* mode/filter list, remember: order matters! */
-.filters =  {
+	.tx_range_list1 = { RIG_FRNG_END, },
+	.rx_range_list2 = {
+		{kHz(150), MHz(30) - kHz(1), DWT_MODES, -1, -1, DWT_VFO, DWT_ANT},
+		{kHz(87.5), MHz(108), RIG_MODE_WFM, -1, -1, DWT_VFO, DWT_ANT},
+		RIG_FRNG_END,
+	},
+	.tx_range_list2 = 	{ RIG_FRNG_END, },
+	.tuning_steps = {
+		{DWT_MODES, 1},
+		RIG_TS_END,
+	},
+	/* mode/filter list, remember: order matters! */
+	.filters = {
 		{RIG_MODE_USB, kHz(22)},	/* FIXME */
 		{RIG_MODE_AM, kHz(9)},	/* FIXME */
 		{RIG_MODE_WFM, kHz(230)},	/* FIXME */
 		RIG_FLT_END,
 	},
 
-.rig_init =     dwtdll_init,
-.rig_cleanup =  dwtdll_cleanup,
-.rig_open =     dwtdll_open,
-.rig_close =    dwtdll_close,
+	.rig_init =		dwtdll_init,
+	.rig_cleanup =		dwtdll_cleanup,
+	.rig_open =		dwtdll_open,
+	.rig_close =		dwtdll_close,
 
-.set_freq =  dwtdll_set_freq,
-.get_freq =  dwtdll_get_freq,
-.set_mode =  dwtdll_set_mode,
-.get_mode =  dwtdll_get_mode,
-.set_level = dwtdll_set_level,
-.get_level = dwtdll_get_level,
-.get_info =  dwtdll_get_info,
+	.set_freq =		dwtdll_set_freq,
+	.get_freq =		dwtdll_get_freq,
+	.set_mode =		dwtdll_set_mode,
+	.get_mode =		dwtdll_get_mode,
+	.set_level =		dwtdll_set_level,
+	.get_level =		dwtdll_get_level,
+	.get_info =		dwtdll_get_info,
 };
 
 
@@ -224,7 +223,8 @@ int dwtdll_init(RIG *rig)
 {
 	struct dwtdll_priv_data *priv;
 
-	priv = (struct dwtdll_priv_data*)malloc(sizeof(struct dwtdll_priv_data));
+	priv = (struct dwtdll_priv_data *)malloc(sizeof(struct dwtdll_priv_data));
+
 	if (!priv) {
 		/* whoops! memory shortage! */
 		return -RIG_ENOMEM;
@@ -235,7 +235,7 @@ int dwtdll_init(RIG *rig)
 
 	if (!priv->dll) {
 		rig_debug(RIG_DEBUG_ERR, "%s: Unable to LoadLibrary %s\n",
-				__FUNCTION__, DWTDLL);
+			  __func__, DWTDLL);
 		free(priv);
 		return -RIG_EIO;	/* huh! */
 	}
@@ -278,7 +278,7 @@ int dwtdll_init(RIG *rig)
 	priv->FrontendGetFmMode =
 		(FNCFrontendGetFmMode) GetProcAddress(priv->dll, "FrontendGetFmMode");
 
-	rig->state.priv = (void*)priv;
+	rig->state.priv = (void *)priv;
 
 	return RIG_OK;
 }
@@ -290,11 +290,13 @@ int dwtdll_open(RIG *rig)
 
 	/* Open DWT receiver */
 	ret = priv->FrontendOpen();
+
 	if (ret < 0)
 		return -RIG_EIO;	/* huh! */
 
 	/* default to DRM mode */
 	ret = priv->FrontendSetMode(eFrontendModeDrm);
+
 	if (ret < 0)
 		return -RIG_EIO;	/* huh! */
 
@@ -308,6 +310,7 @@ int dwtdll_close(RIG *rig)
 
 	/* Open DWT receiver */
 	ret = priv->FrontendClose();
+
 	if (ret < 0)
 		return -RIG_EIO;	/* huh! */
 
@@ -323,6 +326,7 @@ int dwtdll_cleanup(RIG *rig)
 
 	if (rig->state.priv)
 		free(rig->state.priv);
+
 	rig->state.priv = NULL;
 
 	return RIG_OK;
@@ -355,8 +359,11 @@ int dwtdll_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 
 	switch (mode) {
 	case RIG_MODE_USB: dwtmode = eFrontendModeDrm; break;
+
 	case RIG_MODE_AM: dwtmode = eFrontendModeAm; break;
+
 	case RIG_MODE_WFM: dwtmode = eFrontendModeFm; break;
+
 	default:
 		return -RIG_EINVAL;
 	}
@@ -375,11 +382,15 @@ int dwtdll_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
 	switch (dwtmode) {
 	case eFrontendModeDrm: *mode = RIG_MODE_USB; break;
+
 	case eFrontendModeAm: *mode = RIG_MODE_AM; break;
+
 	case eFrontendModeFm: *mode = RIG_MODE_WFM; break;
+
 	default:
 		return -RIG_EPROTO;
 	}
+
 	*width = rig_passband_normal(rig, *mode);
 
 	return RIG_OK;
@@ -389,9 +400,9 @@ int dwtdll_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 int dwtdll_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
 	struct dwtdll_priv_data *priv = (struct dwtdll_priv_data *)rig->state.priv;
-	short ret=0;
+	short ret = 0;
 
-	switch(level) {
+	switch (level) {
 	case RIG_LEVEL_ATT:
 		ret = priv->FrontendSetRfAttenuator(val.i ? 1 : 0);
 		break;
@@ -406,13 +417,15 @@ int dwtdll_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 int dwtdll_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
 	struct dwtdll_priv_data *priv = (struct dwtdll_priv_data *)rig->state.priv;
-	signed short ret=0;
+	signed short ret = 0;
 
-	switch(level) {
+	switch (level) {
 	case RIG_LEVEL_ATT:
 		ret = priv->FrontendGetRfAttenuator();
+
 		if (ret < 0)
 			break;
+
 		/* local vs. DX mode */
 		val->i = ret ? 0 : rig->caps->attenuator[0];
 		break;
@@ -420,17 +433,21 @@ int dwtdll_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 	case RIG_LEVEL_STRENGTH:
 		/* actual RMS signal strength in dBuV */
 		ret = priv->FrontendGetRfLevel();
+
 		if (ret < 0)
 			break;
-	      	/* return actual RMS signal strength in dBuV, -34 to get dB rel S9 */
+
+		/* return actual RMS signal strength in dBuV, -34 to get dB rel S9 */
 		val->i = ret - 34;
 		break;
 
 	case RIG_LEVEL_RAWSTR:
 		/* actual RMS signal strength in dBuV */
 		ret = priv->FrontendGetRfLevel();
+
 		if (ret < 0)
 			break;
+
 		val->i = ret;
 		break;
 
@@ -442,7 +459,7 @@ int dwtdll_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 }
 
 
-static const char* dwtdll_get_info(RIG *rig)
+static const char *dwtdll_get_info(RIG *rig)
 {
 	struct dwtdll_priv_data *priv = (struct dwtdll_priv_data *)rig->state.priv;
 	static char info[22];
@@ -456,11 +473,15 @@ static const char* dwtdll_get_info(RIG *rig)
 }
 
 
-#elif defined(HAVE_LIBUSB) && defined(HAVE_USB_H)
-
+#elif defined(HAVE_LIBUSB) && (defined(HAVE_LIBUSB_H) || defined(HAVE_LIBUSB_1_0_LIBUSB_H))
 
 #include <errno.h>
-#include <usb.h>
+
+#ifdef HAVE_LIBUSB_H
+# include <libusb.h>
+#elif defined HAVE_LIBUSB_1_0_LIBUSB_H
+# include <libusb-1.0/libusb.h>
+#endif
 
 #include "token.h"
 
@@ -481,7 +502,7 @@ static const char* dwtdll_get_info(RIG *rig)
 
 static int dwt_init(RIG *rig);
 static int dwt_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
-static const char * dwt_get_info(RIG *rig);
+static const char *dwt_get_info(RIG *rig);
 
 /*
  * Coding Technologies Digital World Traveller DRM tuner.
@@ -492,77 +513,77 @@ static const char * dwt_get_info(RIG *rig);
  */
 
 const struct rig_caps dwt_caps = {
-.rig_model =  RIG_MODEL_DWT,
-.model_name = "Digital World Traveller",
-.mfg_name =  "Coding Technologies",
-.version =  "0.1",
-.copyright =  "LGPL",
-.status =  RIG_STATUS_UNTESTED,
-.rig_type =  RIG_TYPE_TUNER,
-.ptt_type =  RIG_PTT_NONE,
-.dcd_type =  RIG_DCD_NONE,
-.port_type =  RIG_PORT_USB,
-.serial_rate_min =  9600,	/* don't care */
-.serial_rate_max =  9600,
-.serial_data_bits =  8,
-.serial_stop_bits =  1,
-.serial_parity =  RIG_PARITY_NONE,
-.serial_handshake =  RIG_HANDSHAKE_NONE,
-.write_delay =  0,
-.post_write_delay =  0,
-.timeout =  200,
-.retry = 0,
+	.rig_model =		RIG_MODEL_DWT,
+	.model_name =		"Digital World Traveller",
+	.mfg_name =		"Coding Technologies",
+	.version =		"0.2",
+	.copyright =		"LGPL",
+	.status =		RIG_STATUS_UNTESTED,
+	.rig_type =		RIG_TYPE_TUNER,
+	.ptt_type =		RIG_PTT_NONE,
+	.dcd_type =		RIG_DCD_NONE,
+	.port_type =		RIG_PORT_USB,
+	.serial_rate_min =	9600,	/* don't care */
+	.serial_rate_max =	9600,
+	.serial_data_bits =	8,
+	.serial_stop_bits =	1,
+	.serial_parity =	RIG_PARITY_NONE,
+	.serial_handshake =	RIG_HANDSHAKE_NONE,
+	.write_delay =		0,
+	.post_write_delay =	0,
+	.timeout =		200,
+	.retry =		0,
 
-.has_get_func =  DWT_FUNC,
-.has_set_func =  DWT_FUNC,
-.has_get_level =  DWT_LEVEL_ALL,
-.has_set_level =  RIG_LEVEL_SET(DWT_LEVEL_ALL),
-.has_get_parm =  DWT_PARM_ALL,
-.has_set_parm =  RIG_PARM_SET(DWT_PARM_ALL),
-.level_gran =  {},
-.parm_gran =  {},
-.ctcss_list =  NULL,
-.dcs_list =  NULL,
-.preamp =   { RIG_DBLST_END },
-.attenuator =   { RIG_DBLST_END },
-.max_rit =  Hz(0),
-.max_xit =  Hz(0),
-.max_ifshift =  Hz(0),
-.targetable_vfo =  0,
-.transceive =  RIG_TRN_OFF,
-.bank_qty =   0,
-.chan_desc_sz =  0,
+	.has_get_func =		DWT_FUNC,
+	.has_set_func =		DWT_FUNC,
+	.has_get_level =	DWT_LEVEL_ALL,
+	.has_set_level =	RIG_LEVEL_SET(DWT_LEVEL_ALL),
+	.has_get_parm =		DWT_PARM_ALL,
+	.has_set_parm =		RIG_PARM_SET(DWT_PARM_ALL),
+	.level_gran =		{},
+	.parm_gran =		{},
+	.ctcss_list =		NULL,
+	.dcs_list =		NULL,
+	.preamp =		{ RIG_DBLST_END },
+	.attenuator =		{ RIG_DBLST_END },
+	.max_rit =		Hz(0),
+	.max_xit =		Hz(0),
+	.max_ifshift =		Hz(0),
+	.targetable_vfo =	0,
+	.transceive =		RIG_TRN_OFF,
+	.bank_qty =		0,
+	.chan_desc_sz =		0,
 
-.chan_list =  { RIG_CHAN_END, },
+	.chan_list =		{ RIG_CHAN_END, },
 
-.rx_range_list1 =  {
-    {kHz(150),MHz(30)-kHz(1),DWT_MODES,-1,-1,DWT_VFO},
-    {kHz(87.5),MHz(108),RIG_MODE_WFM,-1,-1,DWT_VFO},
-	RIG_FRNG_END,
-  },
-.tx_range_list1 =  { RIG_FRNG_END, },
-.rx_range_list2 =  {
-    {kHz(150),MHz(30)-kHz(1),DWT_MODES,-1,-1,DWT_VFO},
-    {kHz(87.5),MHz(108),RIG_MODE_WFM,-1,-1,DWT_VFO},
-	RIG_FRNG_END,
-  },
-.tx_range_list2 =  { RIG_FRNG_END, },
-.tuning_steps =  {
-	 {DWT_MODES,kHz(1)},
-	 RIG_TS_END,
+	.rx_range_list1 = {
+		{kHz(150), MHz(30) - kHz(1), DWT_MODES, -1, -1, DWT_VFO},
+		{kHz(87.5), MHz(108), RIG_MODE_WFM, -1, -1, DWT_VFO},
+		RIG_FRNG_END,
 	},
-        /* mode/filter list, remember: order matters! */
-.filters =  {
+	.tx_range_list1 = { RIG_FRNG_END, },
+	.rx_range_list2 = {
+		{kHz(150), MHz(30) - kHz(1), DWT_MODES, -1, -1, DWT_VFO},
+		{kHz(87.5), MHz(108), RIG_MODE_WFM, -1, -1, DWT_VFO},
+		RIG_FRNG_END,
+	},
+	.tx_range_list2 = { RIG_FRNG_END, },
+	.tuning_steps = {
+		{DWT_MODES, kHz(1)},
+		RIG_TS_END,
+	},
+	/* mode/filter list, remember: order matters! */
+	.filters = {
 		{RIG_MODE_USB, kHz(22)},	/* FIXME */
 		{RIG_MODE_AM, kHz(9)},	/* FIXME */
 		{RIG_MODE_WFM, kHz(230)},	/* FIXME */
 		RIG_FLT_END,
 	},
 
-.rig_init =  dwt_init,
+	.rig_init =		dwt_init,
 
-.set_freq =  dwt_set_freq,
-.get_info =  dwt_get_info,
+	.set_freq =		dwt_set_freq,
+	.get_info =		dwt_get_info,
 
 };
 
@@ -583,41 +604,45 @@ int dwt_init(RIG *rig)
 #define MSG_LEN 16
 int dwt_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-	struct usb_dev_handle *udh = rig->state.rigport.handle;
+	libusb_device_handle *udh = rig->state.rigport.handle;
 	int request, value, index;
 	unsigned char buf[MSG_LEN] = { 0x4a, 0x00, 0x03, 0x00, 0xff, 0xff, 0x32 };
 	int requesttype, r;
-	int ifreq = (int)(freq/1000);
+	int ifreq = (int)(freq / 1000);
 
 	/* FIXME */
-  	requesttype = 0x00;
-  	request = 0x00;
-  	value = 0x00;
-  	index = 0x00;
+	requesttype = 0x00;
+	request = 0x00;
+	value = 0x00;
+	index = 0x00;
 
 	buf[8] = ifreq & 0xff;
-	buf[7] = (ifreq>>8) & 0xff;
-	r = usb_control_msg (udh, requesttype, request, value, index,
-			   (char *) buf, 9, 1000);
+	buf[7] = (ifreq >> 8) & 0xff;
+
+	r = libusb_control_transfer(udh, requesttype, request, value, index,
+				    buf, 9, 1000);
+
 	if (r < 0) {
-		/* we get EPIPE if the firmware stalls the endpoint. */
-		if (errno != EPIPE)
-			rig_debug (RIG_DEBUG_ERR,
-					"usb_control_msg failed: %s\n",
-					usb_strerror ());
+		rig_debug(RIG_DEBUG_ERR,
+			  "libusb_control_transfer failed: %s\n",
+			  libusb_error_name(r));
 		return -RIG_EIO;
 	}
 
 	return RIG_OK;
 }
 
-const char * dwt_get_info(RIG *rig)
+/* Rem: not reentrant */
+const char *dwt_get_info(RIG *rig)
 {
 	static char buf[64];
-	struct usb_dev_handle *udh = rig->state.rigport.handle;
-	struct usb_device *q = usb_device(udh);
+	libusb_device_handle *udh = rig->state.rigport.handle;
+	struct libusb_device_descriptor desc;
 
-	sprintf(buf, "Dev %04d", q->descriptor.bcdDevice);
+	/* always succeeds since libusb-1.0.16 */
+	libusb_get_device_descriptor(libusb_get_device(udh), &desc);
+
+	sprintf(buf, "Dev %04d", desc.bcdDevice);
 
 	return buf;
 }
