@@ -1,12 +1,12 @@
 #!/bin/bash
 
-# Builds Hamlib 1.2.x Win32 binary distribution.
+# Builds Hamlib 3.x Win32 binary distribution.
 
 # A script to build a set of Win32 binary DLLs from a Hamlib tarball.
 # This script assumes that the Hamlib tarball has been extracted to the
-# directory specified in $build_dir and that libusb-win32-bin-1.x.y.z has also
-# been extracted to $build_dir and a libusb.pc file has been created.  The
-# MS VC++Toolkit must also be installed.
+# directory specified in $BUILD_DIR and that libusb-win32-bin-1.x.y.z has also
+# been extracted to $BUILD_DIR.  The MS VC++Toolkit must also be installed
+# and working with Wine.
 #
 # See README.build-win32 for complete details.
 
@@ -17,6 +17,13 @@ BUILD_DIR=~/builds
 # Set this to LibUSB archive extracted in $BUILD_DIR
 LIBUSB_VER=libusb-win32-bin-1.2.4.0
 
+# uncomment the correct HOST_ARCH= line for your minGW installation
+# HOST_ARCH=i586-mingw32msvc
+HOST_ARCH=i686-w64-mingw32
+
+# Set to the strip name for your version of minGW
+# HOST_ARCH_STRIP=i586-mingw32msvc-strip
+HOST_ARCH_STRIP=i686-w64-mingw32-strip
 
 # Error return codes.  See /usr/include/sysexits.h
 EX_USAGE=64
@@ -39,7 +46,7 @@ else
 	exit $EX_NOINPUT
 fi
 
-RELEASE=`/usr/bin/awk 'BEGIN{FS="["; RS="]"} /\[1\./ {print $2}' ./configure.ac`
+RELEASE=`/usr/bin/awk 'BEGIN{FS="["; RS="]"} /\[3\./ {print $2}' ./configure.ac`
 INST_DIR=`pwd`/mingw-inst
 ZIP_DIR=`pwd`/hamlib-win32-${RELEASE}
 LIBUSB_WIN32_BIN_PATH=${BUILD_DIR}/${LIBUSB_VER}
@@ -51,7 +58,8 @@ What is it?
 ===========
 
 This ZIP archive or Windows installer contains a build of Hamlib-$RELEASE
-cross-compiled for Win32 using MinGW under Xubuntu Linux 10.10 (nice, heh!).
+cross-compiled for MS Windows 32 bit using MinGW under Debian GNU/Linux
+(nice, heh!).
 
 The DLL has a cdecl interface for MS VC++.
 
@@ -59,6 +67,10 @@ This software is copyrighted. The library license is LGPL, and the *.EXE
 files licenses are GPL.  Hamlib comes WITHOUT ANY WARRANTY. See the
 LICENSE.txt, COPYING.txt, and COPYING.LIB.txt files.
 
+A draft user manual in HTML format is included in the doc directory.  As it
+covers the four main Hamlib utilities the respective PDF files are no longer
+included separately.
+
 
 Installation and Configuration
 ==============================
@@ -68,14 +80,12 @@ reasonable choice.
 
 Make sure *all* the .DLL files are in your PATH (leave them in the bin
 directory and set the PATH).  To set the PATH environment variable in
-Windows 2000, Windows XP, and Windows 7 (need info on Vista) do the
-following:
+Windows 2000, Windows XP, and Windows 7 (need info on Vista and Windows 8)
+do the following:
 
  * W2k/XP: Right-click on "My Computer"
    Win7: Right-click on "Computer"
 
- * Select "Properties" from the pop-up menu
-
  * W2k/XP: Click the "Advanced" tab of the "System Properties" dialog
    Win7: Click the "Advanced system settings" link in the System dialog
 
@@ -94,7 +104,7 @@ following:
    a semi-colon ';' after the last path before adding the Hamlib path (NB. The
    entire path is highlighted and will be erased upon typing a character so
    click in the box to unselect the text first.  The PATH is important!!)
-   Append the Hamlib path, e.g. C:\Program Files\hamlib-win32-1.2.14~git\bin
+   Append the Hamlib path, e.g. C:\Program Files\hamlib-win32-3.0~git\bin
 
  * Click OK for all three dialog boxes to save your changes.
 
@@ -138,6 +148,7 @@ Uninstall
 To uninstall, simply delete the Hamlib directory.  You may wish to edit the
 PATH as above to remove the Hamlib bin path, if desired.
 
+
 Information for Win32 Programmers
 =================================
 
@@ -169,52 +180,56 @@ http://www.hamlib.org
 END_OF_README
 
 
-# Import internal ./libltdl and build it for mingw32
-libtoolize --ltdl
-cd libltdl; ./configure --host=i586-mingw32msvc && make; cd ..
-
 # Configure and build hamlib for mingw32, with libusb-win32
 
-./configure --disable-static \
- --host=i586-mingw32msvc \
+./configure --host=${HOST_ARCH} \
  --prefix=`pwd`/mingw-inst \
- --without-rpc-backends \
  --without-cxx-binding \
- PKG_CONFIG_LIBDIR=${LIBUSB_WIN32_BIN_PATH}/lib/pkgconfig \
- LIBTOOL=./libltdl/libtool
+ --disable-static \
+ CPPFLAGS="-I${LIBUSB_WIN32_BIN_PATH}/include" \
+ LDFLAGS="-L${LIBUSB_WIN32_BIN_PATH}/lib/gcc"
+
 
 make install
 
-mkdir -p ${ZIP_DIR}/bin ${ZIP_DIR}/lib/msvc ${ZIP_DIR}/lib/gcc ${ZIP_DIR}/include ${ZIP_DIR}/pdf
+mkdir -p ${ZIP_DIR}/bin ${ZIP_DIR}/lib/msvc ${ZIP_DIR}/lib/gcc ${ZIP_DIR}/include ${ZIP_DIR}/pdf ${ZIP_DIR}/doc
 cp -a src/libhamlib.def ${ZIP_DIR}/lib/msvc/libhamlib-2.def; todos ${ZIP_DIR}/lib/msvc/libhamlib-2.def
 cp -a ${INST_DIR}/include/hamlib ${ZIP_DIR}/include/.; todos ${ZIP_DIR}/include/hamlib/*.h
+cp -a doc/Hamlib_design.png ${ZIP_DIR}/doc
+cp -a doc/hamlib.html ${ZIP_DIR}/doc
 
 # C++ binding is useless on win32 because of ABI
 rm ${ZIP_DIR}/include/hamlib/{rig,rot}class.h
 
 for f in AUTHORS ChangeLog COPYING COPYING.LIB LICENSE README README.betatester README.win32-bin THANKS ; do \
-	cp -a ${f} ${ZIP_DIR}/${f}.txt ; todos ${ZIP_DIR}/${f}.txt ; done
+    cp -a ${f} ${ZIP_DIR}/${f}.txt ; todos ${ZIP_DIR}/${f}.txt ; done
 
 # Generate PDF documents from nroff formatted man files
 cd tests
 
-for f in rigctl.1 rigctld.8 rigmem.1 rigsmtr.1 rigswr.1 rotctl.1 rotctld.8 ; do \
-	groff -mandoc >${f}.ps ${f} ; ps2pdf ${f}.ps ; rm ${f}.ps ; \
+for f in rigmem.1 rigsmtr.1 rigswr.1; do \
+    groff -mandoc >${f}.ps ${f} ; ps2pdf ${f}.ps ; rm ${f}.ps ; \
     cp -a ${f}.pdf ${ZIP_DIR}/pdf/. ; done
 
 cd ${BUILD_DIR}/$1
 
 # Copy build files into specific locations for Zip file
 cp -a ${INST_DIR}/bin/{rigctld.exe,rigctl.exe,rigmem.exe,rigsmtr.exe,rigswr.exe,rotctld.exe,rotctl.exe} ${ZIP_DIR}/bin/.
-cp -a ${INST_DIR}/lib/hamlib/hamlib-*.dll ${ZIP_DIR}/bin/.
 cp -a ${INST_DIR}/bin/libhamlib-?.dll ${ZIP_DIR}/bin/.
 cp -a ${INST_DIR}/lib/libhamlib.dll.a ${ZIP_DIR}/lib/gcc/.
 
-# NB: Do not strip libusb0.dll
-i586-mingw32msvc-strip ${ZIP_DIR}/bin/*.exe ${ZIP_DIR}/bin/*hamlib-*.dll
+# NB: Strip Hamlib DLLs and EXEs
+${HOST_ARCH_STRIP} ${ZIP_DIR}/bin/*.exe ${ZIP_DIR}/bin/*hamlib-*.dll
+
+# Copy needed third party DLLs
+cp -a /usr/i686-w64-mingw32/lib/libwinpthread-1.dll ${ZIP_DIR}/bin/.
 cp -a ${LIBUSB_WIN32_BIN_PATH}/bin/x86/libusb0_x86.dll ${ZIP_DIR}/bin/libusb0.dll
 
+# Required for MinGW with GCC 4.8
+cp -a /usr/lib/gcc/i686-w64-mingw32/4.8/libgcc_s_sjlj-1.dll ${ZIP_DIR}/bin/libgcc_s_sjlj-1.dll
+
 # Need VC++ free toolkit installed (default Wine directory installation shown)
 ( cd ${ZIP_DIR}/lib/msvc/ && wine ~/.wine/drive_c/Program\ Files/Microsoft\ Visual\ C++\ Toolkit\ 2003/bin/link.exe /lib /machine:i386 /def:libhamlib-2.def )
+
 zip -r hamlib-win32-${RELEASE}.zip `basename ${ZIP_DIR}`
 
