@@ -654,6 +654,7 @@ static struct {
 	{ RIG_SCAN_VFO, "VFO" },
 	{ RIG_SCAN_PLT, "PLT" },
 	{ RIG_SCAN_NONE, "" },
+	{ -1, NULL }
 };
 
 /**
@@ -841,5 +842,11 @@ void HAMLIB_API rig_force_cache_timeout(struct timeval *tv)
     tv->tv_usec = 0;
 }
 
+int no_restore_ai;
+
+void HAMLIB_API rig_no_restore_ai()
+{
+	no_restore_ai = -1;
+}
 
 /** @} */
