@@ -73,6 +73,36 @@
 static int wsstarted;
 #endif
 
+static void handle_error (enum rig_debug_level_e lvl, const char *msg)
+{
+	int e;
+#ifdef __MINGW32__
+	LPVOID lpMsgBuf;
+
+	lpMsgBuf = (LPVOID)"Unknown error";
+	e = WSAGetLastError();
+	if (FormatMessage(
+			FORMAT_MESSAGE_ALLOCATE_BUFFER |
+			FORMAT_MESSAGE_FROM_SYSTEM |
+			FORMAT_MESSAGE_IGNORE_INSERTS,
+			NULL, e,
+			MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
+				// Default language
+			(LPTSTR)&lpMsgBuf, 0, NULL))
+		{
+			rig_debug (lvl, "%s: Network error %d: %s\n", msg, e, lpMsgBuf);
+			LocalFree(lpMsgBuf);
+		}
+	else
+		{
+			rig_debug (lvl, "%s: Network error %d\n", msg, e);
+		}
+#else
+	e = errno;
+	rig_debug (lvl, "%s: Network error %d: %s\n", msg, e, strerror (e));
+#endif
+}
+
 /**
  * \brief Open network port using rig.state data
  *
@@ -87,9 +117,9 @@ int network_open(hamlib_port_t *rp, int default_port)
 {
 	int fd;				/* File descriptor for the port */
 	int status;
-	struct addrinfo hints, *res;
-	char *portstr;
-	char hostname[FILPATHLEN] = "127.0.0.1";
+	struct addrinfo hints, *res, *saved_res;
+	char *hoststr = NULL, *portstr = NULL, *bracketstr1, *bracketstr2;
+	char hostname[FILPATHLEN];
 	char defaultportstr[8];
 
 #ifdef __MINGW32__
@@ -110,48 +140,89 @@ int network_open(hamlib_port_t *rp, int default_port)
 	else
 		hints.ai_socktype = SOCK_STREAM;
 
-	if (rp->pathname[0] == ':') {
-		portstr = rp->pathname+1;
-	} else {
-		strncpy(hostname, rp->pathname, FILPATHLEN-1);
-
-		/* search last ':', because IPv6 may have some */
-		portstr = strrchr(hostname, ':');
-		if (portstr) {
-			*portstr++ = '\0';
-		} else {
-			sprintf(defaultportstr, "%d", default_port);
-			portstr = defaultportstr;
+	hoststr = NULL;								/* default of all local interfaces */
+	if (rp->pathname[0] == ':')
+		{
+			portstr = rp->pathname + 1;
+		}
+	else
+		{
+			if (strlen (rp->pathname))
+				{
+					strncpy(hostname, rp->pathname, FILPATHLEN-1);
+					hoststr = hostname;
+					/* look for IPv6 numeric form [<addr>] */
+					bracketstr1 = strchr(hoststr, '[');
+					bracketstr2 = strrchr(hoststr, ']');
+					if (bracketstr1 && bracketstr2 && bracketstr2 > bracketstr1)
+						{
+							hoststr = bracketstr1 + 1;
+							*bracketstr2 = '\0';
+							portstr = bracketstr2 + 1; /* possible port after ]: */
+						}
+					else
+						{
+							bracketstr2 = NULL;
+							portstr = hoststr; /* possible port after : */
+						}
+					/* search last ':' */
+					portstr = strrchr(portstr, ':');
+					if (portstr)
+						{
+							*portstr++ = '\0';
+						}
+				}
+			if (!portstr)
+				{
+					sprintf(defaultportstr, "%d", default_port);
+					portstr = defaultportstr;
+				}
 		}
-	}
 
-	status=getaddrinfo(hostname, portstr, &hints, &res);
+	status=getaddrinfo(hoststr, portstr, &hints, &res);
 	if (status != 0) {
 		rig_debug(RIG_DEBUG_ERR, "Cannot get host \"%s\": %s\n",
 					rp->pathname, gai_strerror(errno));
 		return -RIG_ECONF;
 	}
+	saved_res = res;
 
 	/* we don't want a signal when connection get broken */
 #ifdef SIGPIPE
 	signal(SIGPIPE, SIG_IGN);
 #endif
 
-	fd = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
-	if (fd < 0)
-		return -RIG_EIO;
+	do
+		{
+			fd = socket(res->ai_family, res->ai_socktype, res->ai_protocol);
+			if (fd < 0)
+				{
+					handle_error (RIG_DEBUG_ERR, "socket");
+					freeaddrinfo (saved_res);
+					return -RIG_EIO;
+				}
 
-	status = connect(fd, res->ai_addr, res->ai_addrlen);
-	freeaddrinfo(res);
-	if (status < 0) {
-		rig_debug(RIG_DEBUG_ERR, "Cannot open NET device \"%s\": %s\n",
-					rp->pathname, strerror(errno));
-		close(fd);
+			if ((status = connect(fd, res->ai_addr, res->ai_addrlen)) == 0)
+				{
+					break;
+				}
+			handle_error (RIG_DEBUG_WARN, "connect (trying next interface)");
+
+#ifdef __MINGW32__
+			closesocket (fd);
+#else
+			close (fd);
+#endif
+		} while ((res = res->ai_next) != NULL);
+
+	freeaddrinfo (saved_res);
+
+	if (NULL == res) {
+		rig_debug (RIG_DEBUG_ERR, "Failed to connect to %s\n" , rp->pathname);
 		return -RIG_EIO;
 	}
 
 	rp->fd = fd;
-
 	return RIG_OK;
 }
 
