@@ -67,6 +67,7 @@
 #include "network.h"
 #include "event.h"
 #include "cm108.h"
+#include "gpio.h"
 
 /**
  * \brief Hamlib release number
@@ -77,11 +78,18 @@
  * the hamlib_version string.  Changing the size provokes a warning from the
  * dynamic loader.
  */
+const char *hamlib_license = "LGPL";
 const char hamlib_version[21] = "Hamlib " PACKAGE_VERSION;
+const char *hamlib_version2 = "Hamlib " PACKAGE_VERSION;
 
 /**
  * \brief Hamlib copyright notice
  */
+const char *hamlib_copyright2 =
+  "Copyright (C) 2000-2012 Stephane Fillod\n"
+  "Copyright (C) 2000-2003 Frank Singleton\n"
+  "This is free software; see the source for copying conditions.  There is NO\n"
+  "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.";
 const char hamlib_copyright[231] = /* hamlib 1.2 ABI specifies 231 bytes */
   "Copyright (C) 2000-2012 Stephane Fillod\n"
   "Copyright (C) 2000-2003 Frank Singleton\n"
@@ -127,6 +135,7 @@ const char hamlib_copyright[231] = /* hamlib 1.2 ABI specifies 231 bytes */
 #define DEFAULT_CM108_PTT_BITNUM 2
 #endif
 
+#define DEFAULT_GPIO_PORT "0"
 
 #define CHECK_RIG_ARG(r) (!(r) || !(r)->caps || !(r)->state.comm_state)
 
@@ -307,6 +316,9 @@ RIG * HAMLIB_API rig_init(rig_model_t rig_model)
 
 	rs = &rig->state;
 
+	rs->rigport.fd = -1;
+	rs->pttport.fd = -1;
+	rs->pttport.fd = -1;
 	rs->comm_state = 0;
 	rs->rigport.type.rig = caps->port_type; /* default from caps */
 
@@ -331,6 +343,10 @@ RIG * HAMLIB_API rig_init(rig_model_t rig_model)
 	strncpy(rs->rigport.pathname, DEFAULT_CM108_PORT, FILPATHLEN);
 	rs->rigport.parm.cm108.ptt_bitnum = DEFAULT_CM108_PTT_BITNUM;
 	break;
+	
+	case RIG_PORT_GPIO:
+	strncpy(rs->rigport.pathname, DEFAULT_GPIO_PORT, FILPATHLEN);
+	break;
 
 	case RIG_PORT_NETWORK:
 	case RIG_PORT_UDP_NETWORK:
@@ -551,6 +567,7 @@ int HAMLIB_API rig_open(RIG *rig)
 								status = ser_set_rts(&rs->pttport, 0);
 							}
 					}
+	      ser_close(&rs->pttport);
 	    }
 	  break;
 	case RIG_PTT_PARALLEL:
@@ -575,6 +592,26 @@ int HAMLIB_API rig_open(RIG *rig)
 		else
 			cm108_ptt_set(&rs->pttport, RIG_PTT_OFF);
 		break;
+	case RIG_PTT_GPIO:
+		rs->pttport.fd = gpio_open(&rs->pttport, 1);
+		if (rs->pttport.fd < 0) {
+			rig_debug(RIG_DEBUG_ERR, 
+			    "Cannot open PTT device \"%s\"\n",
+			    rs->pttport.pathname);
+			status = -RIG_EIO;
+		} else
+			gpio_ptt_set(&rs->pttport, RIG_PTT_OFF);
+		break;
+	case RIG_PTT_GPION:
+		rs->pttport.fd = gpio_open(&rs->pttport, 0);
+		if (rs->pttport.fd < 0) {
+			rig_debug(RIG_DEBUG_ERR, 
+			    "Cannot open PTT device \"%s\"\n",
+			    rs->pttport.pathname);
+			status = -RIG_EIO;
+		} else
+			gpio_ptt_set(&rs->pttport, RIG_PTT_OFF);
+		break;
 	default:
 		rig_debug(RIG_DEBUG_ERR, "Unsupported PTT type %d\n",
               rs->pttport.type.ptt);
@@ -727,6 +764,10 @@ int HAMLIB_API rig_close(RIG *rig)
 	cm108_ptt_set(&rs->pttport, RIG_PTT_OFF);
 	port_close(&rs->pttport, RIG_PORT_CM108);
 		break;
+	case RIG_PTT_GPIO:
+	case RIG_PTT_GPION:
+		gpio_ptt_set(&rs->pttport, RIG_PTT_OFF);
+		port_close(&rs->pttport, RIG_PORT_GPIO);
 	default:
 		rig_debug(RIG_DEBUG_ERR, "Unsupported PTT type %d\n",
 						rs->pttport.type.ptt);
@@ -925,8 +966,11 @@ int HAMLIB_API rig_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
  * \param mode	The mode to set to
  * \param width	The passband width to set to
  *
- * Sets the mode and associated passband of the target VFO.
- * The passband \a width must be supported by the backend of the rig.
+ * Sets the mode and associated passband of the target VFO.  The
+ * passband \a width must be supported by the backend of the rig or
+ * the special value RIG_PASSBAND_NOCHANGE which leaves the passband
+ * unchanged from the current value or default for the mode determined
+ * by the rig.
  *
  * \return RIG_OK if the operation has been sucessful, otherwise
  * a negative value if an error occured (in which case, cause is
@@ -1249,6 +1293,7 @@ int HAMLIB_API rig_get_vfo(RIG *rig, vfo_t *vfo)
 int HAMLIB_API rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
 	const struct rig_caps *caps;
+	struct rig_state * rs = &rig->state;
 	int retcode, rc2;
 	vfo_t curr_vfo;
 
@@ -1288,10 +1333,56 @@ int HAMLIB_API rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 		break;
 
 	case RIG_PTT_SERIAL_DTR:
-		return ser_set_dtr(&rig->state.pttport, ptt!=RIG_PTT_OFF);
+	  if (strcmp(rs->pttport.pathname, rs->rigport.pathname)
+				&& ptt!=RIG_PTT_OFF && rs->pttport.fd < 0)
+	    {
+	      rs->pttport.fd = ser_open(&rs->pttport);
+	      if (rs->pttport.fd < 0)
+          {
+            rig_debug(RIG_DEBUG_ERR, "Cannot open PTT device \"%s\"\n",
+                      rs->pttport.pathname);
+            return -RIG_EIO;
+          }
+				/* Needed on Linux because the serial port driver sets RTS/DTR
+					 high on open - set both low since we offer no control of
+					 the non-PTT line and low is better than high */
+				retcode = ser_set_rts(&rs->pttport, 0);
+				if (RIG_OK != retcode) return retcode;
+	    }
+		retcode = ser_set_dtr(&rig->state.pttport, ptt!=RIG_PTT_OFF);
+	  if (strcmp(rs->pttport.pathname, rs->rigport.pathname)
+				&& ptt==RIG_PTT_OFF)
+	    {
+				/* free the port */
+	      ser_close(&rs->pttport);
+	    }
+		return retcode;
 
 	case RIG_PTT_SERIAL_RTS:
-		return ser_set_rts(&rig->state.pttport, ptt!=RIG_PTT_OFF);
+	  if (strcmp(rs->pttport.pathname, rs->rigport.pathname)
+				&& ptt!=RIG_PTT_OFF && rs->pttport.fd < 0)
+	    {
+	      rs->pttport.fd = ser_open(&rs->pttport);
+	      if (rs->pttport.fd < 0)
+          {
+            rig_debug(RIG_DEBUG_ERR, "Cannot open PTT device \"%s\"\n",
+                      rs->pttport.pathname);
+            return -RIG_EIO;
+          }
+				/* Needed on Linux because the serial port driver sets RTS/DTR
+					 high on open - set both low since we offer no control of
+					 the non-PTT line and low is better than high */
+				retcode = ser_set_dtr(&rs->pttport, 0);
+				if (RIG_OK != retcode) return retcode;
+	    }
+		retcode = ser_set_rts(&rig->state.pttport, ptt!=RIG_PTT_OFF);
+	  if (strcmp(rs->pttport.pathname, rs->rigport.pathname)
+				&& ptt==RIG_PTT_OFF)
+	    {
+				/* free the port */
+	      ser_close(&rs->pttport);
+	    }
+		return retcode;
 
 	case RIG_PTT_PARALLEL:
 		return par_ptt_set(&rig->state.pttport, ptt);
@@ -1299,6 +1390,10 @@ int HAMLIB_API rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 	case RIG_PTT_CM108:
 		return cm108_ptt_set(&rig->state.pttport, ptt);
 
+	case RIG_PTT_GPIO:
+	case RIG_PTT_GPION:
+		return gpio_ptt_set(&rig->state.pttport, ptt);
+
 	case RIG_PTT_NONE:
 		return -RIG_ENAVAIL;	/* not available */
 	default:
@@ -1325,7 +1420,9 @@ int HAMLIB_API rig_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 int HAMLIB_API rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
 	const struct rig_caps *caps;
-	int retcode, rc2, status;
+	struct rig_state * rs = &rig->state;
+	int retcode = RIG_OK;
+	int rc2, status;
 	vfo_t curr_vfo;
 
 	if (CHECK_RIG_ARG(rig) || !ptt)
@@ -1366,16 +1463,34 @@ int HAMLIB_API rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 		if (caps->get_ptt)
 			return caps->get_ptt(rig, vfo, ptt);
 
-		retcode = ser_get_rts(&rig->state.pttport, &status);
-		*ptt = status ? RIG_PTT_ON : RIG_PTT_OFF;
+	  if (strcmp(rs->pttport.pathname, rs->rigport.pathname)
+				&& rs->pttport.fd < 0)
+	    {
+				/* port is closed so assume PTT off */
+				*ptt = RIG_PTT_OFF;
+	    }
+		else
+			{
+				retcode = ser_get_rts(&rig->state.pttport, &status);
+				*ptt = status ? RIG_PTT_ON : RIG_PTT_OFF;
+			}
 		return retcode;
 
 	case RIG_PTT_SERIAL_DTR:
 		if (caps->get_ptt)
 			return caps->get_ptt(rig, vfo, ptt);
 
-		retcode = ser_get_dtr(&rig->state.pttport, &status);
-		*ptt = status ? RIG_PTT_ON : RIG_PTT_OFF;
+	  if (strcmp(rs->pttport.pathname, rs->rigport.pathname)
+				&& rs->pttport.fd < 0)
+	    {
+				/* port is closed so assume PTT off */
+				*ptt = RIG_PTT_OFF;
+	    }
+		else
+			{
+				retcode = ser_get_dtr(&rig->state.pttport, &status);
+				*ptt = status ? RIG_PTT_ON : RIG_PTT_OFF;
+			}
 		return retcode;
 
 	case RIG_PTT_PARALLEL:
@@ -1390,6 +1505,13 @@ int HAMLIB_API rig_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 
 		return cm108_ptt_get(&rig->state.pttport, ptt);
 
+	case RIG_PTT_GPIO:
+	case RIG_PTT_GPION:
+		if (caps->get_ptt)
+			return caps->get_ptt(rig, vfo, ptt);
+
+		return gpio_ptt_get(&rig->state.pttport, ptt);
+
 	case RIG_PTT_NONE:
 		return -RIG_ENAVAIL;	/* not available */
 
@@ -1838,7 +1960,10 @@ int HAMLIB_API rig_get_split_freq(RIG *rig, vfo_t vfo, freq_t *tx_freq)
  * \param rig	The rig handle
  * \param vfo	The target VFO
  * \param tx_mode	The transmit split mode to set to
- * \param tx_width	The transmit split width to set to
+ * \param tx_width The transmit split width to set to or the special
+ * value RIG_PASSBAND_NOCHANGE which leaves the passband unchanged
+ * from the current value or default for the mode determined by the
+ * rig.
  *
  *  Sets the split(TX) mode.
  *
@@ -1992,6 +2117,100 @@ int HAMLIB_API rig_get_split_mode(RIG *rig, vfo_t vfo, rmode_t *tx_mode, pbwidth
 }
 
 
+/**
+ * \brief set the split frequency and mode
+ * \param rig	The rig handle
+ * \param vfo	The target VFO
+ * \param tx_freq The transmit frequency to set to
+ * \param tx_mode	The transmit split mode to set to
+ * \param tx_width The transmit split width to set to or the special
+ * value RIG_PASSBAND_NOCHANGE which leaves the passband unchanged
+ * from the current value or default for the mode determined by the
+ * rig.
+ *
+ *  Sets the split(TX) frequency and mode.
+ *
+ *  This function maybe optimized on some rig back ends, where the TX
+ *  VFO cannot be directly addressed, to reduce the number of times
+ *  the rig VFOs have to be exchanged or swapped to complete this
+ *  combined function.
+ *
+ * \return RIG_OK if the operation has been sucessful, otherwise
+ * a negative value if an error occured (in which case, cause is
+ * set appropriately).
+ *
+ * \sa rig_set_split_freq(), rig_set_split_mode(), rig_get_split_freq_mode()
+ */
+
+int HAMLIB_API rig_set_split_freq_mode(RIG *rig, vfo_t vfo, freq_t tx_freq, rmode_t tx_mode, pbwidth_t tx_width)
+{
+	const struct rig_caps *caps;
+	int retcode;
+
+	if (CHECK_RIG_ARG(rig))
+		return -RIG_EINVAL;
+
+	caps = rig->caps;
+
+  if (caps->set_split_freq_mode) {
+    return caps->set_split_freq_mode (rig, vfo, tx_freq, tx_mode, tx_width);
+  }
+
+  retcode = rig_set_split_freq (rig, vfo, tx_freq);
+  if (RIG_OK == retcode) {
+    retcode = rig_set_split_mode (rig, vfo, tx_mode, tx_width);
+  }
+
+  return retcode;
+}
+
+/**
+ * \brief get the current split frequency and mode
+ * \param rig	The rig handle
+ * \param vfo	The target VFO
+ * \param tx_freq The location where to store the current transmit frequency
+ * \param tx_mode	The location where to store the current transmit split mode
+ * \param tx_width	The location where to store the current transmit split width
+ *
+ *  Retrieves the current split(TX) frequency, mode and passband.
+ *  If the backend is unable to determine the width, the \a tx_width
+ *  will be set to RIG_PASSBAND_NORMAL as a default.
+ *  The value stored at \a tx_mode location equals RIG_MODE_NONE
+ *  when the current mode of the VFO is not defined (e.g. blank memory).
+ *
+ *  This function maybe optimized on some rig back ends, where the TX
+ *  VFO cannot be directly addressed, to reduce the number of times
+ *  the rig VFOs have to be exchanged or swapped to complete this
+ *  combined function.
+ *
+ * \return RIG_OK if the operation has been sucessful, otherwise
+ * a negative value if an error occured (in which case, cause is
+ * set appropriately).
+ *
+ * \sa rig_get_split_freq(), rig_get_split_mode(), rig_set_split_freq_mode()
+ */
+int HAMLIB_API rig_get_split_freq_mode(RIG *rig, vfo_t vfo, freq_t *tx_freq, rmode_t *tx_mode, pbwidth_t *tx_width)
+{
+	const struct rig_caps *caps;
+	int retcode;
+
+	if (CHECK_RIG_ARG(rig) || !tx_freq || !tx_mode || !tx_width)
+		return -RIG_EINVAL;
+
+	caps = rig->caps;
+
+  if (caps->get_split_freq_mode) {
+    return caps->get_split_freq_mode (rig, vfo, tx_freq, tx_mode, tx_width);
+  }
+
+  retcode = rig_get_split_freq (rig, vfo, tx_freq);
+  if (RIG_OK == retcode) {
+    retcode = rig_get_split_mode (rig, vfo, tx_mode, tx_width);
+  }
+
+  return retcode;
+}
+
 /**
  * \brief set the split mode
  * \param rig	The rig handle
@@ -3129,4 +3348,19 @@ const char* HAMLIB_API rig_get_info(RIG *rig)
 	return rig->caps->get_info(rig);
 }
 
+const char* HAMLIB_API rig_license()
+{
+	return hamlib_license;
+}
+
+const char* HAMLIB_API rig_version()
+{
+	return hamlib_version2;
+}
+
+const char* HAMLIB_API rig_copyright()
+{
+	return hamlib_copyright2;
+}
+
 /*! @} */
