@@ -2,21 +2,20 @@
  *  Hamlib Interface - token header
  *  Copyright (c) 2000-2009 by Stephane Fillod
  *
- *	$Id: token.h,v 1.5 2006-10-28 03:49:46 aa6e Exp $
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -28,7 +27,7 @@
 /**
  * \brief Token definitions
  * \file token.h
- * 
+ *
  */
 
 #ifndef _TOKEN_H
@@ -86,7 +85,8 @@
 #define TOK_DCD_TYPE	TOKEN_FRONTEND(32)
 /** \brief  DCD pathname override */
 #define TOK_DCD_PATHNAME	TOKEN_FRONTEND(33)
-
+/** \brief  CM108 GPIO bit number for PTT */
+#define TOK_PTT_BITNUM        TOKEN_FRONTEND(34)
 /*
  * rig specific tokens
  */
