@@ -85,7 +85,7 @@ struct tt588_priv_data {
 // #define TT588_FSK '6'
 #define EOM "\015"      /* CR */
 #define FALSE 0
-#define TRUE (!FALSE)
+#define TRUE 1
 
 static int tt588_init(RIG *rig);
 static int tt588_reset(RIG *rig, reset_t reset);
@@ -152,7 +152,7 @@ const struct rig_caps tt588_caps = {
 .ctcss_list =  NULL,
 .dcs_list =  NULL,
 .preamp =   { 10, RIG_DBLST_END }, /* FIXME: real value */
-.attenuator =   { 15, RIG_DBLST_END },
+.attenuator =   { 6, 12, 18, RIG_DBLST_END },
 .max_rit =  Hz(8192),
 .max_xit =  Hz(8192),
 .max_ifshift =  kHz(2),
@@ -230,7 +230,6 @@ const struct rig_caps tt588_caps = {
 .set_xit = tt588_set_xit,
 .get_rit = tt588_get_xit,
 .set_rit = tt588_set_rit,
-.attenuator =   { 6, 12, 18, RIG_DBLST_END },
 // Antenna functions only in remote mode -- prototypes provided
 //.get_ant = tt588_get_ant,
 //.set_ant = tt588_set_ant
@@ -700,12 +699,10 @@ int tt588_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 		return retval;
 
 	/* Set rx filter bandwidth. */
-
-	if (width == RIG_PASSBAND_NORMAL)
-		width = tt588_filter_number(rig_passband_normal(rig, mode));
-	else
-		width = tt588_filter_number((int) width);
-
+	if (RIG_PASSBAND_NOCHANGE == width) return retval;
+	if (RIG_PASSBAND_NORMAL == width)
+		width = rig_passband_normal (rig, mode);
+	width = tt588_filter_number((int) width);
 	cmd_len = sprintf((char *) cmdbuf, "*W%c" EOM, (unsigned char) width);
 	return tt588_transaction (rig, (char *) cmdbuf, cmd_len, NULL, NULL);
 }
