@@ -118,7 +118,7 @@ static pthread_mutex_t rot_mutex = PTHREAD_MUTEX_INITIALIZER;
 #ifdef HAVE_LIBREADLINE
 static char *input_line = (char *)NULL;
 static char *result = (char *)NULL;
-static char *parsed_input[sizeof(char) * 7];
+static char *parsed_input[sizeof(char*) * 7];
 static const int have_rl = 1;
 
 #ifdef HAVE_READLINE_HISTORY
@@ -331,6 +331,7 @@ static int scanfc(FILE *fin, const char *format, void *p)
 			if (errno == EINTR)
 				continue;
 			rig_debug(RIG_DEBUG_ERR, "fscanf: %s\n", strerror(errno));
+			rig_debug(RIG_DEBUG_ERR, "fscanf: parsing '%s' with '%s'\n", p, format);
 		}
 		return ret;
 	} while(1);
@@ -354,7 +355,7 @@ static int next_word (char *buffer, int argc, char *argv[], int newline)
   if (!reading_stdin)
     {
       if (optind >= argc) return EOF;
-      else if ('-' == argv[optind][0])
+      else if (newline && '-' == argv[optind][0] && 1 == strlen (argv[optind]))
         {
           ++optind;
           reading_stdin = 1;
@@ -1115,7 +1116,7 @@ int print_conf_list(const struct confparams *cfp, rig_ptr_t data)
 					cfp->u.n.min, cfp->u.n.max, cfp->u.n.step);
 		break;
 	case RIG_CONF_COMBO:
-		if (!cfp->u.c.combostr)
+		if (!cfp->u.c.combostr[0])
 			break;
 		printf("\tCombo: %s", cfp->u.c.combostr[0]);
 		for (i = 1 ; i < RIG_COMBO_MAX && cfp->u.c.combostr[i]; i++)
