@@ -6,8 +6,31 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
+
 #include <hamlib/rig.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+/* HAVE_SSLEEP is defined when Windows Sleep is found
+ * HAVE_SLEEP is defined when POSIX sleep is found
+ * _WIN32 is defined when compiling with MinGW
+ *
+ * When cross-compiling from POSIX to Windows using MinGW, HAVE_SLEEP
+ * will often be defined by configure although it is not supported by
+ * MinGW.  So substitute the sleep definition below in such a case and
+ * when compiling on Windows using MinGW where HAVE_SLEEP will be
+ * undefined.
+ *
+ * FIXME:  Needs better handling for all versions of MinGW.
+ *
+ */
+#if (defined(HAVE_SSLEEP) || defined(_WIN32)) && (!defined(HAVE_SLEEP))
+#include "hl_sleep.h"
+#endif
+
+
 #define SERIAL_PORT "/dev/ttyS0"
 
 int myfreq_event(RIG *rig, vfo_t vfo, freq_t freq, rig_ptr_t arg)
@@ -89,5 +112,3 @@ int main (int argc, char *argv[])
 
 	return 0;
 }
-
-
