@@ -728,7 +728,9 @@ int ft980_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
     return -RIG_EINVAL;         /* sorry, wrong MODE */
   }
 
-  if (width != RIG_PASSBAND_NORMAL && width < rig_passband_normal(rig, mode)) {
+  if (width != RIG_PASSBAND_NOCHANGE
+      && width != RIG_PASSBAND_NORMAL
+      && width < rig_passband_normal(rig, mode)) {
     switch(md) {
        case MD_CW: md = MD_CWN; break;
        case MD_AM: md = MD_AMN; break;
