@@ -34,6 +34,7 @@
 #define _NEWCAT_H 1
 
 #include <tones.h>
+#include <token.h>
 
 /* Handy constants */
 
@@ -49,7 +50,7 @@
 typedef char ncboolean;
 
 /* shared function version */
-#define NEWCAT_VER "0.22"
+#define NEWCAT_VER "0.23"
 
 /* Hopefully large enough for future use, 128 chars plus '\0' */
 #define NEWCAT_DATA_LEN                 129
@@ -68,6 +69,8 @@ typedef char ncboolean;
 	.ctcss_sql = 1,\
 }
 
+extern const struct confparams newcat_cfg_params[];
+
 /*
  * future - private data
  *
@@ -84,6 +87,8 @@ struct newcat_priv_data {
     int                 rig_id;                         /* rig id from CAT Command ID; */
     int width_frequency; /* width of FA/FB freq response */
     int offset_rit; /* offset of rit in response */
+    int trn_state;  /* AI state found at startup */
+		int fast_set_commands; /* do not check for ACK/NAK; needed for high throughput > 100 commands/s */
 };
 
 
@@ -114,7 +119,6 @@ struct newcat_priv_data {
  *
  */
 
-
 /*
  * newcat function definitions.
  *
@@ -125,6 +129,9 @@ int newcat_cleanup(RIG *rig);
 int newcat_open(RIG *rig);
 int newcat_close(RIG *rig);
 
+int newcat_set_conf(RIG *rig, token_t token, const char *val);
+int newcat_get_conf(RIG *rig, token_t token, char *val);
+
 int newcat_set_freq(RIG *rig, vfo_t vfo, freq_t freq);
 int newcat_get_freq(RIG *rig, vfo_t vfo, freq_t *freq);
 
